class BgSoc:
    class CabExtracto:
        _tbl = "CCABEXTRACTO"
        account_code = "CCABEXTRACTO1"
        account_name = "CCABEXTRACTO2"
        excercise_fiscal = "CCABEXTRACTO3"
        page_number = "CCABEXTRACTO4"
        previous_balance = "CCABEXTRACTO5"
        previous_balance_currency_internal = "CCABEXTRACTO6"
        date = "CCABEXTRACTO7"
        later_balance = "CCABEXTRACTO8"
        later_balance_currency_internal = "CCABEXTRACTO9"
        currency = "CCABEXTRACTO10"

    class Cuentas:
        _tbl = "CCUENTAS"
        code = "CCUENTAS1"
        denomination = "CCUENTAS2"

    class FichaLeasing:
        _tbl = "CFICHALEASING"
        code = "CFICHALEASING1"
        currency = "CFICHALEASING2"
        creditor = "CFICHALEASING3"
        tax_type = "CFICHALEASING6"
        account_code_pgc = "CFICHALEASING18"
        account_code = "CFICHALEASING12"

    class LineasFichaLeasing:
        _tbl = "CLINEASFICHALEASING"
        date = "CLINEASFICHALEASING1"
        base = "CLINEASFICHALEASING3"
        tax = "CLINEASFICHALEASING8"
        date_recieved = "CLINEASFICHALEASING15"
        leasing_code = "CLINEASFICHALEASING16"

    class AlbaranesCompra:
        _tbl = "TALBARANESCOMPRA"
        is_delivery_note = "TALBARANESCOMPRA1"
        is_direct_invoice = "TALBARANESCOMPRA2"
        document_type = "TALBARANESCOMPRA3"
        is_billable = "TALBARANESCOMPRA4"
        update_stock = "TALBARANESCOMPRA5"
        code = "TALBARANESCOMPRA6"
        date = "TALBARANESCOMPRA7"
        currency = "TALBARANESCOMPRA8"
        order_code = "TALBARANESCOMPRA9"
        date_recieved = "TALBARANESCOMPRA10"
        provider_code = "TALBARANESCOMPRA11"
        warehouse_discharged = "TALBARANESCOMPRA12"
        worksite_discharged = "TALBARANESCOMPRA13"
        warehouse_recieved = "TALBARANESCOMPRA15"
        delegation_code = "TALBARANESCOMPRA16"
        invoice_series = "TALBARANESCOMPRA17"
        invoice_code = "TALBARANESCOMPRA18"
        invoice_code_external = "TALBARANESCOMPRA19"
        document_date = "TALBARANESCOMPRA20"
        invoice_recieved_date = "TALBARANESCOMPRA21"
        total_bruto_currency = "TALBARANESCOMPRA22"
        total_bruto_currency_internal = "TALBARANESCOMPRA23"
        discount_percentage = "TALBARANESCOMPRA24"
        discount_currency = "TALBARANESCOMPRA25"
        discount_currency_internal = "TALBARANESCOMPRA26"
        discount_in_concept_of = "TALBARANESCOMPRA27"
        base_currency_1 = "TALBARANESCOMPRA28"
        base_currency_internal_1 = "TALBARANESCOMPRA29"
        tax_percentage_1 = "TALBARANESCOMPRA30"
        tax_amount_1 = "TALBARANESCOMPRA31"
        tax_amount_internal_1 = "TALBARANESCOMPRA32"
        tax_recharge_percentage_1 = "TALBARANESCOMPRA33"
        tax_recharge_amount_1 = "TALBARANESCOMPRA34"
        tax_recharge_amount_internal_1 = "TALBARANESCOMPRA35"
        base_currency_2 = "TALBARANESCOMPRA36"
        base_currency_internal_2 = "TALBARANESCOMPRA37"
        tax_percentage_2 = "TALBARANESCOMPRA38"
        tax_amount_2 = "TALBARANESCOMPRA39"
        tax_amount_internal_2 = "TALBARANESCOMPRA40"
        tax_recharge_rercentage_2 = "TALBARANESCOMPRA41"
        tax_recharge_amount_2 = "TALBARANESCOMPRA42"
        tax_recharge_amount_internal_2 = "TALBARANESCOMPRA43"
        base_currency_3 = "TALBARANESCOMPRA44"
        base_currency_internal_3 = "TALBARANESCOMPRA45"
        tax_percentage_3 = "TALBARANESCOMPRA46"
        tax_amount_3 = "TALBARANESCOMPRA47"
        tax_amount_internal_3 = "TALBARANESCOMPRA48"
        tax_recharge_percentage_3 = "TALBARANESCOMPRA49"
        tax_recharge_amount_3 = "TALBARANESCOMPRA50"
        tax_recharge_amount_internal_3 = "TALBARANESCOMPRA51"
        base_currency_4 = "TALBARANESCOMPRA64"
        base_currency_internal_4 = "TALBARANESCOMPRA65"
        tax_percentage_4 = "TALBARANESCOMPRA66"
        tax_amount_4 = "TALBARANESCOMPRA67"
        tax_amount_internal_4 = "TALBARANESCOMPRA68"
        tax_recharge_percentage_4 = "TALBARANESCOMPRA69"
        tax_recharge_amount_4 = "TALBARANESCOMPRA70"
        tax_recharge_amount_internal_4 = "TALBARANESCOMPRA71"
        total_delivery_note_currency = "TALBARANESCOMPRA52"
        total_delivery_note_internal = "TALBARANESCOMPRA53"
        total_delivery_note_counter_value = "TALBARANESCOMPRA54"
        payment_state = "TALBARANESCOMPRA56"
        tax_type_1 = "TALBARANESCOMPRA58"
        tax_type_2 = "TALBARANESCOMPRA59"
        tax_type_3 = "TALBARANESCOMPRA60"
        tax_type_4 = "TALBARANESCOMPRA61"
        keep_discount_amount = "TALBARANESCOMPRA62"
        invoice_year = "TALBARANESCOMPRA63"

    class ValoresCuentasFacturacionCompras:
        _tbl = "TVALORESCUENTASFACTURACIONCOMPRAS"
        account = "TVALORESCUENTASFACTURACIONCOMPRAS1"
        dh = "TVALORESCUENTASFACTURACIONCOMPRAS2"
        amount = "TVALORESCUENTASFACTURACIONCOMPRAS3"
        account_amount = "TVALORESCUENTASFACTURACIONCOMPRAS4"
        tax_type = "TVALORESCUENTASFACTURACIONCOMPRAS5"
        iva = "TVALORESCUENTASFACTURACIONCOMPRAS6"
        iva_amount = "TVALORESCUENTASFACTURACIONCOMPRAS7"
        internal_iva_amount = "TVALORESCUENTASFACTURACIONCOMPRAS8"
        re = "TVALORESCUENTASFACTURACIONCOMPRAS9"
        re_amount = "TVALORESCUENTASFACTURACIONCOMPRAS10"
        internal_re_amount = "TVALORESCUENTASFACTURACIONCOMPRAS11"
        aditional_concept = "TVALORESCUENTASFACTURACIONCOMPRAS12"
        document_year = "TVALORESCUENTASFACTURACIONCOMPRAS13"
        document_series = "TVALORESCUENTASFACTURACIONCOMPRAS14"
        document_number = "TVALORESCUENTASFACTURACIONCOMPRAS15"
        is_auto = "TVALORESCUENTASFACTURACIONCOMPRAS16"
        is_deductible = "TVALORESCUENTASFACTURACIONCOMPRAS17"
        autonumeric_row = "TVALORESCUENTASFACTURACIONCOMPRAS18"
        cost_center = "TVALORESCUENTASFACTURACIONCOMPRAS19"
        units = "TVALORESCUENTASFACTURACIONCOMPRAS20"
        kilos = "TVALORESCUENTASFACTURACIONCOMPRAS21"
        aditional_3 = "TVALORESCUENTASFACTURACIONCOMPRAS22"
        numeric_index = "TVALORESCUENTASFACTURACIONCOMPRAS23"

    class AutorizacionesIso:
        _tbl = "TAUTORIZACIONESISO"
        type = "TAUTORIZACIONESISO1"
        date = "TAUTORIZACIONESISO2"
        worker_code = "TAUTORIZACIONESISO3"
        firm_id = "TAUTORIZACIONESISO6"
        id_auth = "TAUTORIZACIONESISO7"

    class Almacenes:
        _tbl = "TALMACENES"
        code = "TALMACENES1"
        name = "TALMACENES2"
        street = "TALMACENES3"
        zip_code = "TALMACENES4"
        city = "TALMACENES5"
        province = "TALMACENES6"
        country = "TALMACENES7"
        phone = "TALMACENES8"
        fax = "TALMACENES9"
        mail = "TALMACENES10"
        in_charge = "TALMACENES11"
        observations = "TALMACENES14"

    class Articulos:
        _tbl = "TARTICULOS"
        ref = "TARTICULOS1"
        ref_associated = "TARTICULOS2"
        bar_code = "TARTICULOS3"
        description_short = "TARTICULOS4"
        family_code = "TARTICULOS5"
        description = "TARTICULOS6"
        sub_family_code = "TARTICULOS7"
        group_code = "TARTICULOS8"
        alternate_article_code = "TARTICULOS9"
        output_tax_code = "TARTICULOS10"
        pvp_date = "TARTICULOS11"
        pvp_amount = "TARTICULOS12"
        pvp_previous_date = "TARTICULOS13"
        pvp_previous_amount = "TARTICULOS14"
        pvp_later_date = "TARTICULOS15"
        pvp_later_amount = "TARTICULOS16"
        pvp_amount_tax_included = "TARTICULOS17"
        pvp_previous_date_2 = "TARTICULOS18"
        pvp_previous_amount_2 = "TARTICULOS19"
        pvp_later_date_2 = "TARTICULOS20"
        pvp_later_amount_2 = "TARTICULOS21"
        margin = "TARTICULOS22"
        puc_date = "TARTICULOS23"
        puc = "TARTICULOS24"
        pmp_date = "TARTICULOS26"
        pmp = "TARTICULOS27"
        puc_special_price_date = "TARTICULOS29"
        puc_special_price = "TARTICULOS30"
        stock_control_code = "TARTICULOS32"
        stock_inclusion_date = "TARTICULOS33"
        last_sell_date = "TARTICULOS34"
        last_buy_date = "TARTICULOS35"
        same_units_like_deliverynote = "TARTICULOS36"
        units_x = "TARTICULOS37"
        units_n = "TARTICULOS38"
        lock_articles_in = "TARTICULOS39"
        assign_installation_time = "TARTICULOS40"
        char_effect_recalc_prices = "TARTICULOS41"
        discount_percantage = "TARTICULOS42"
        put_on_sell_units_automatic = "TARTICULOS43"
        final_product = "TARTICULOS44"
        service__provided = "TARTICULOS45"
        sub_product = "TARTICULOS46"
        tool = "TARTICULOS47"
        raw_material = "TARTICULOS48"
        others = "TARTICULOS49"
        free_field_1 = "TARTICULOS50"
        free_field_2 = "TARTICULOS51"
        free_field_3 = "TARTICULOS52"
        manufacturer_code = "TARTICULOS53"
        bulk_article = "TARTICULOS54"
        format_code = "TARTICULOS55"
        increase_percentage_per_unit = "TARTICULOS56"
        format_code_2 = "TARTICULOS57"
        pvp_per_unit = "TARTICULOS58"
        ask_for_units = "TARTICULOS59"
        ask_for_packages = "TARTICULOS60"
        package_code_1 = "TARTICULOS61"
        package_units_billing_1 = "TARTICULOS62"
        package_tare_1 = "TARTICULOS63"
        package_type_buy = "TARTICULOS64"
        package_type_sell = "TARTICULOS65"
        package_code_2 = "TARTICULOS66"
        package_units_billing_2 = "TARTICULOS67"
        package_tare_2 = "TARTICULOS68"
        package_code_3 = "TARTICULOS69"
        package_units_billing_3 = "TARTICULOS70"
        package_tare_3 = "TARTICULOS71"
        package_code_4 = "TARTICULOS72"
        package_units_billing_4 = "TARTICULOS73"
        package_tare_4 = "TARTICULOS74"
        package_code_5 = "TARTICULOS75"
        package_units_billing_5 = "TARTICULOS76"
        package_tare_5 = "TARTICULOS77"
        month_first_1 = "TARTICULOS78"
        month_final_1 = "TARTICULOS79"
        stock_min_1 = "TARTICULOS80"
        stock_max_1 = "TARTICULOS81"
        month_first_2 = "TARTICULOS82"
        month_final_2 = "TARTICULOS83"
        stock_min_2 = "TARTICULOS84"
        stock_max_2 = "TARTICULOS85"
        month_first_3 = "TARTICULOS86"
        month_final_3 = "TARTICULOS87"
        stock_min_3 = "TARTICULOS88"
        stock_max_3 = "TARTICULOS89"
        month_first_4 = "TARTICULOS90"
        month_final_4 = "TARTICULOS91"
        stock_min_4 = "TARTICULOS92"
        stock_max_4 = "TARTICULOS93"
        control_type_units_in_orders = "TARTICULOS94"
        unit_types_invoicing = "TARTICULOS95"
        unit_types_in_provider_orders = "TARTICULOS96"
        observations = "TARTICULOS101"
        serial_number_required = "TARTICULOS111"
        lot_number_required = "TARTICULOS112"
        stock = "TARTICULOS122"
        stock_reserved_client_orders = "TARTICULOS124"
        stock_ordered_to_provider = "TARTICULOS126"
        convertor_weight_units = "TARTICULOS138"
        convertor_value_entry = "TARTICULOS139"
        convertor_unit_entry = "TARTICULOS140"
        convertor_value_invoicing = "TARTICULOS141"
        convertor_unit_invoicing = "TARTICULOS142"
        stock_future_reserved_client_orders = "TARTICULOS144"
        last_cost = "TARTICULOS169"
        last_provider_code = "TARTICULOS183"
        treatment_code = "TARTICULOS203"
        pgc_code_purchases = "TARTICULOS270"
        pgc_code_devolutions = "TARTICULOS271"
        pgc_code_sells = "TARTICULOS272"

    class AvisosCheckList:
        _tbl = "TAVISOSCHECKLIST"
        ot_code = "TAVISOSCHECKLIST1"
        autonumeric_line = "TAVISOSCHECKLIST2"
        element_code = "TAVISOSCHECKLIST3"
        treatment_code = "TAVISOSCHECKLIST4"
        task_code = "TAVISOSCHECKLIST5"
        value = "TAVISOSCHECKLIST6"
        worker = "TAVISOSCHECKLIST7"
        line_index = "TAVISOSCHECKLIST8"
    
    class AvisosCheckListImp:
        _tbl = "TAVISOSCHECKLISTIMP"
        ot_code = "TAVISOSCHECKLISTIMP1"
        treatment = "TAVISOSCHECKLISTIMP2"
        numeric_index = "TAVISOSCHECKLISTIMP3"
        concept = "TAVISOSCHECKLISTIMP4"
        column1 = "TAVISOSCHECKLISTIMP5"
        alignment1 = "TAVISOSCHECKLISTIMP6"
        worker1 = "TAVISOSCHECKLISTIMP7"
        column2 = "TAVISOSCHECKLISTIMP8"
        alignment2 = "TAVISOSCHECKLISTIMP9"
        worker2 = "TAVISOSCHECKLISTIMP10"
        column3 = "TAVISOSCHECKLISTIMP11"
        alignment3 = "TAVISOSCHECKLISTIMP12"
        worker3 = "TAVISOSCHECKLISTIMP13"
        column4 = "TAVISOSCHECKLISTIMP14"
        alignment4 = "TAVISOSCHECKLISTIMP15"
        worker4 = "TAVISOSCHECKLISTIMP16"
        column5 = "TAVISOSCHECKLISTIMP17"
        alignment5 = "TAVISOSCHECKLISTIMP18"
        worker5 = "TAVISOSCHECKLISTIMP19"
        column6 = "TAVISOSCHECKLISTIMP20"
        alignment6 = "TAVISOSCHECKLISTIMP21"
        worker6 = "TAVISOSCHECKLISTIMP22"
        column7 = "TAVISOSCHECKLISTIMP23"
        alignment7 = "TAVISOSCHECKLISTIMP24"
        worker7 = "TAVISOSCHECKLISTIMP25"
        column8 = "TAVISOSCHECKLISTIMP26"
        alignment8 = "TAVISOSCHECKLISTIMP27"
        worker8 = "TAVISOSCHECKLISTIMP28"
        autonumeric_line = "TAVISOSCHECKLISTIMP29"


    class MantenimientosSAT:
        _tbl = "TMANTENIMIENTOSSAT"
        code = "TMANTENIMIENTOSSAT1"
        desc = "TMANTENIMIENTOSSAT2"
        hour_price = "TMANTENIMIENTOSSAT3"
        hour_price_internal = "TMANTENIMIENTOSSAT4"
        currency = "TMANTENIMIENTOSSAT5"
        tasks_do_all = "TMANTENIMIENTOSSAT6"



    class ValoresMantenimientosSAT:
        _tbl = "TVALORESMANTENIMIENTOSSAT"
        task = "TVALORESMANTENIMIENTOSSAT1"
        minutes = "TVALORESMANTENIMIENTOSSAT2"
        revisions = "TVALORESMANTENIMIENTOSSAT3"
        treatment = "TVALORESMANTENIMIENTOSSAT4"
        autonumeric_line = "TVALORESMANTENIMIENTOSSAT5"
        preventive = "TVALORESMANTENIMIENTOSSAT6"
        numeric_index = "TVALORESMANTENIMIENTOSSAT7"



    class AvisosHistorialLlamadas:
        _tbl = "TAVISOSHISTORIALLLAMADAS"
        ot_code = "TAVISOSHISTORIALLLAMADAS1"
        date = "TAVISOSHISTORIALLLAMADAS3"
        hour = "TAVISOSHISTORIALLLAMADAS4"
        contact = "TAVISOSHISTORIALLLAMADAS5"
        comments = "TAVISOSHISTORIALLLAMADAS7"
        numeric_index = "TAVISOSHISTORIALLLAMADAS8"

    class AvisosElementos:
        _tbl = "TAVISOSELEMENTOS"
        element_code = "TAVISOSELEMENTOS1"
        ot_code = "TAVISOSELEMENTOS4"
        index_numerico = "TAVISOSELEMENTOS6"


    class AvisosReparacionesClientes:
        _tbl = "TAVISOSREPARACIONESCLIENTES"
        ot_code = "TAVISOSREPARACIONESCLIENTES1"
        date_notice = "TAVISOSREPARACIONESCLIENTES2"
        date_attention = "TAVISOSREPARACIONESCLIENTES4"
        client_code = "TAVISOSREPARACIONESCLIENTES5"
        client_name = "TAVISOSREPARACIONESCLIENTES6"
        client_nif = "TAVISOSREPARACIONESCLIENTES7"
        client_street = "TAVISOSREPARACIONESCLIENTES8"
        client_zip_code = "TAVISOSREPARACIONESCLIENTES9"
        client_city = "TAVISOSREPARACIONESCLIENTES10"
        client_province = "TAVISOSREPARACIONESCLIENTES11"
        client_country = "TAVISOSREPARACIONESCLIENTES12"
        client_phone = "TAVISOSREPARACIONESCLIENTES13"
        client_fax = "TAVISOSREPARACIONESCLIENTES14"
        project_code = "TAVISOSREPARACIONESCLIENTES15"
        in_charge_code = "TAVISOSREPARACIONESCLIENTES16"
        worker_code1 = "TAVISOSREPARACIONESCLIENTES17"
        worker_code2 = "TAVISOSREPARACIONESCLIENTES18"
        worker_code3 = "TAVISOSREPARACIONESCLIENTES19"
        failure_description = "TAVISOSREPARACIONESCLIENTES20"
        failure_observation = "TAVISOSREPARACIONESCLIENTES21"
        sell_document_code = "TAVISOSREPARACIONESCLIENTES24"
        notice_type = "TAVISOSREPARACIONESCLIENTES25"
        sell_document_type = "TAVISOSREPARACIONESCLIENTES26"
        is_client = "TAVISOSREPARACIONESCLIENTES27"
        notice_state = "TAVISOSREPARACIONESCLIENTES28"
        kilometers = "TAVISOSREPARACIONESCLIENTES30"
        deposit = "TAVISOSREPARACIONESCLIENTES31"
        date_reparation_planned = "TAVISOSREPARACIONESCLIENTES32"
        project_observations = "TAVISOSREPARACIONESCLIENTES34"
        client_invoice_to_sat = "TAVISOSREPARACIONESCLIENTES35"
        revision_number = "TAVISOSREPARACIONESCLIENTES36"
        contract_source = "TAVISOSREPARACIONESCLIENTES37"
        material_amount = "TAVISOSREPARACIONESCLIENTES38"
        material_amount_internal = "TAVISOSREPARACIONESCLIENTES39"
        material_cost = "TAVISOSREPARACIONESCLIENTES40"
        material_cost_internal = "TAVISOSREPARACIONESCLIENTES41"
        works_amount = "TAVISOSREPARACIONESCLIENTES42"
        works_amount_internal = "TAVISOSREPARACIONESCLIENTES43"
        works_cost = "TAVISOSREPARACIONESCLIENTES44"
        works_cost_internal = "TAVISOSREPARACIONESCLIENTES45"
        works_hours_real = "TAVISOSREPARACIONESCLIENTES46"
        works_hours_billable = "TAVISOSREPARACIONESCLIENTES47"
        time_of_call = "TAVISOSREPARACIONESCLIENTES48"
        quotation_series = "TAVISOSREPARACIONESCLIENTES53"
        quotation_code = "TAVISOSREPARACIONESCLIENTES54"
        date_attention_planned = "TAVISOSREPARACIONESCLIENTES56"
        contract_code = "TAVISOSREPARACIONESCLIENTES60"
        client_mobile = "TAVISOSREPARACIONESCLIENTES68"
        work_team = "TAVISOSREPARACIONESCLIENTES79"
        project_code_invoice = "TAVISOSREPARACIONESCLIENTES80"
        time_attention_planned_start = "TAVISOSREPARACIONESCLIENTES84"
        time_attention_planned_end = "TAVISOSREPARACIONESCLIENTES85"
        warehouse = "TAVISOSREPARACIONESCLIENTES88"
        free_comments_1 = "TAVISOSREPARACIONESCLIENTES90"
        free_comments_2 = "TAVISOSREPARACIONESCLIENTES91"
        free_comments_3 = "TAVISOSREPARACIONESCLIENTES92"
        free_comments_4 = "TAVISOSREPARACIONESCLIENTES93"
        free_comments_5 = "TAVISOSREPARACIONESCLIENTES94"
        notice_time = "TAVISOSREPARACIONESCLIENTES104"
        client_country_code = "TAVISOSREPARACIONESCLIENTES107"
        comission_agent_code = "TAVISOSREPARACIONESCLIENTES112"
        in_charge_code_header = "TAVISOSREPARACIONESCLIENTES119"
        worker_code1_header = "TAVISOSREPARACIONESCLIENTES120"
        worker_code2_header = "TAVISOSREPARACIONESCLIENTES121"
        worker_code3_header = "TAVISOSREPARACIONESCLIENTES122"
        publish_to_pi_connect = "TAVISOSREPARACIONESCLIENTES126"
        section_code = "TAVISOSREPARACIONESCLIENTES128"
        fee_code ="TAVISOSREPARACIONESCLIENTES157"

    class IntervencionesAvisos:
        _tbl = "TINTERVENCIONESAVISOS"
        status = "TINTERVENCIONESAVISOS1"
        date = "TINTERVENCIONESAVISOS2"
        travel_time = "TINTERVENCIONESAVISOS3"
        hour_start = "TINTERVENCIONESAVISOS4"
        hour_end = "TINTERVENCIONESAVISOS5"
        intervention_time = "TINTERVENCIONESAVISOS6"
        task_code = "TINTERVENCIONESAVISOS7"
        task_desc = "TINTERVENCIONESAVISOS8"
        ot_code = "TINTERVENCIONESAVISOS9"
        auto_numeric_line = "TINTERVENCIONESAVISOS10"
        numeric_index = "TINTERVENCIONESAVISOS11"
        team_code = "TINTERVENCIONESAVISOS12"
        in_charge_code = "TINTERVENCIONESAVISOS13"
        worker_code1 = "TINTERVENCIONESAVISOS14"
        worker_code2 = "TINTERVENCIONESAVISOS15"
        worker_code3 = "TINTERVENCIONESAVISOS16"
    class ArticulosAvisos:
        _tbl = "TARTICULOSAVISOS"
        code = "TARTICULOSAVISOS1"
        desc = "TARTICULOSAVISOS2"
        units = "TARTICULOSAVISOS3"
        observations = "TARTICULOSAVISOS4"
        ot_code = "TARTICULOSAVISOS5"
        auto_numeric_line = "TARTICULOSAVISOS6"
        entry_type = "TARTICULOSAVISOS7"
        units_total = "TARTICULOSAVISOS8"
        price = "TARTICULOSAVISOS9"
        discount = "TARTICULOSAVISOS10"
        amount = "TARTICULOSAVISOS11"
        cost = "TARTICULOSAVISOS12"
        serial_number = "TARTICULOSAVISOS13"
        lot_number = "TARTICULOSAVISOS14"
        location = "TARTICULOSAVISOS15"
        billing_type = "TARTICULOSAVISOS16"
        warranty_type = "TARTICULOSAVISOS17"
        element = "TARTICULOSAVISOS18"
        date = "TARTICULOSAVISOS19"
        task = "TARTICULOSAVISOS20"
        task_desc = "TARTICULOSAVISOS21"
        line_index = "TARTICULOSAVISOS22"
        margin = "TARTICULOSAVISOS23"

    class CostesEspeciales:
        _tbl = "TCOSTESESPECIALES"
        client_code = "TCOSTESESPECIALES1"
        project_code = "TCOSTESESPECIALES2"
        observations = "TCOSTESESPECIALES4"
        currency = "TCOSTESESPECIALES8"

    class CodigoDeVenta:
        _tbl = "TCODIGODEVENTA"
        code = "TCODIGODEVENTA1"
        aim_code = "TCODIGODEVENTA2"
        aim_name = "TCODIGODEVENTA3"

    class ContactosProveedores:
        _tbl = "TCONTACTOSPROVEEDORES"
        department = "TCONTACTOSPROVEEDORES1"
        name = "TCONTACTOSPROVEEDORES2"
        email = "TCONTACTOSPROVEEDORES5"
        provider_code = "TCONTACTOSPROVEEDORES6"

    class ControlOperarios:
        _tbl = "TCONTROLOPERARIOS"
        employee = "TCONTROLOPERARIOS1"
        task = "TCONTROLOPERARIOS2"
        task_desc = "TCONTROLOPERARIOS3"
        hours = "TCONTROLOPERARIOS4"
        hour_type = "TCONTROLOPERARIOS5"
        pvp = "TCONTROLOPERARIOS6"
        amount = "TCONTROLOPERARIOS8"
        cost = "TCONTROLOPERARIOS9"
        am_pm = "TCONTROLOPERARIOS10"
        delivery_note_id = "TCONTROLOPERARIOS11"
        batch = "TCONTROLOPERARIOS12"
        date = "TCONTROLOPERARIOS13"
        pvp_accountant = "TCONTROLOPERARIOS14"
        amount_accountant = "TCONTROLOPERARIOS15"
        cost_accountant = "TCONTROLOPERARIOS16"
        professional_category_code = "TCONTROLOPERARIOS18"
        project = "TCONTROLOPERARIOS19"
        client = "TCONTROLOPERARIOS20"
        part_code = "TCONTROLOPERARIOS21"
        margin_unitary_accountant = "TCONTROLOPERARIOS22"
        margin_unitary = "TCONTROLOPERARIOS23"
        margin_unitray_percentage = "TCONTROLOPERARIOS24"
        amount_margin_accountant = "TCONTROLOPERARIOS25"
        margin = "TCONTROLOPERARIOS26"
        part_type = "TCONTROLOPERARIOS27"
        budget_project_series = "TCONTROLOPERARIOS29"
        budget_project_code = "TCONTROLOPERARIOS30"
        position = "TCONTROLOPERARIOS36"
        observations = "TCONTROLOPERARIOS38"
        date_settlement = "TCONTROLOPERARIOS40"
        time_to_bill = "TCONTROLOPERARIOS60"

    class Clientes:
        _tbl = "TCLIENTES"
        code = "TCLIENTES1"
        name = "TCLIENTES2"
        accounting_account = "TCLIENTES3"
        name_usual = "TCLIENTES4"
        street = "TCLIENTES5"
        zip_code = "TCLIENTES6"
        city = "TCLIENTES7"
        province = "TCLIENTES8"
        country = "TCLIENTES9"
        phone = "TCLIENTES10"
        fax = "TCLIENTES11"
        www = "TCLIENTES12"
        email = "TCLIENTES13"
        nif = "TCLIENTES14"
        date_register = "TCLIENTES17"
        language_code = "TCLIENTES18"
        client_group = "TCLIENTES19"
        observations = "TCLIENTES24"
        discount_type = "TCLIENTES32"
        tax_regime = "TCLIENTES35"
        commission_agent = "TCLIENTES36"
        apply_equivalence_surcharge = "TCLIENTES37"
        usual_freight_table = "TCLIENTES38"
        client_type = "TCLIENTES39"
        payment_method = "TCLIENTES40"
        payment_day_1 = "TCLIENTES41"
        payment_day_2 = "TCLIENTES42"
        payment_day_3 = "TCLIENTES43"
        month_dont_pay = "TCLIENTES44"
        usual_income_account = "TCLIENTES51"
        disable_sells_overselling = "TCLIENTES52"
        disable_sells_to_client = "TCLIENTES53"
        default_delivery_address_code = "TCLIENTES63"
        mailing_code = "TCLIENTES67"
        risks_control = "TCLIENTES73"
        last_sell_date = "TCLIENTES74"
        boss_zone = "TCLIENTES153"
        boss_area = "TCLIENTES154"
        send_invoices_in_electronic_format = "TCLIENTES156"
        mobile = "TCLIENTES158"
        country_code = "TCLIENTES162"

    class ClientesContactos:
        _tbl = "TCLIENTESCONTACTOS"
        department = "TCLIENTESCONTACTOS1"
        name = "TCLIENTESCONTACTOS2"
        phone = "TCLIENTESCONTACTOS3"
        fax = "TCLIENTESCONTACTOS4"
        email = "TCLIENTESCONTACTOS5"
        client_code = "TCLIENTESCONTACTOS6"
        nif = "TCLIENTESCONTACTOS8"
        mobile = "TCLIENTESCONTACTOS9"
        numeric_index = "TCLIENTESCONTACTOS19"

    class ValoresMasDirecciones:
        _tbl = "TVALORESMASDIRECCIONES"
        line_number = "TVALORESMASDIRECCIONES1"
        street = "TVALORESMASDIRECCIONES2"
        zip_code = "TVALORESMASDIRECCIONES3"
        city = "TVALORESMASDIRECCIONES4"
        province = "TVALORESMASDIRECCIONES5"
        client_code = "TVALORESMASDIRECCIONES9"
        country = "TVALORESMASDIRECCIONES10"
        phone = "TVALORESMASDIRECCIONES15"
        fax = "TVALORESMASDIRECCIONES16"
        email = "TVALORESMASDIRECCIONES17"

    class Delgaciones:
        _tbl = "TDELEGACIONES"
        code = "TDELEGACIONES1"
        name = "TDELEGACIONES2"
        soc = "TDELEGACIONES3"

    class Envases:
        _tbl = "TENVASES"
        code = "TENVASES1"
        name = "TENVASES2"

    class FaltasStock:
        _tbl = "TFALTASSTOCK"
        document_code = "TFALTASSTOCK1"
        user = "TFALTASSTOCK2"
        date = "TFALTASSTOCK3"
        time = "TFALTASSTOCK4"
        article = "TFALTASSTOCK5"
        amount = "TFALTASSTOCK6"
        client = "TFALTASSTOCK7"
        observations = "TFALTASSTOCK8"

    class FacturasCompras:
        _tbl = "TFACTURASCOMPRAS"
        invoice_date = "TFACTURASCOMPRAS1"
        provider_code = "TFACTURASCOMPRAS2"
        invoice_received_date = "TFACTURASCOMPRAS3"  # check this #TODO
        invoice_number = "TFACTURASCOMPRAS4"
        year = "TFACTURASCOMPRAS5"
        series = "TFACTURASCOMPRAS6"
        document_code = "TFACTURASCOMPRAS7"
        currency = "TFACTURASCOMPRAS8"
        withholding_tax_base = "TFACTURASCOMPRAS9"
        withholding_total_invoice = "TFACTURASCOMPRAS10"
        account_code_pgc = "TFACTURASCOMPRAS11"
        withholding_ammount_currency = "TFACTURASCOMPRAS12"
        withholding_ammount_currency_accounting = "TFACTURASCOMPRAS13"
        base_currency_1 = "TFACTURASCOMPRAS14"
        base_currency_accounting_1 = "TFACTURASCOMPRAS15"
        tax_type_1 = "TFACTURASCOMPRAS16"
        tax_percentage_1 = "TFACTURASCOMPRAS17"
        tax_amount_currency_1 = "TFACTURASCOMPRAS18"
        amount_currency_accounting_1 = "TFACTURASCOMPRAS19"
        base_currency_2 = "TFACTURASCOMPRAS20"
        base_currency_accounting_2 = "TFACTURASCOMPRAS21"
        tax_type_2 = "TFACTURASCOMPRAS22"
        tax_percentage_2 = "TFACTURASCOMPRAS23"
        tax_amount_currency_2 = "TFACTURASCOMPRAS24"
        amount_currency_accounting_2 = "TFACTURASCOMPRAS25"
        base_currency_3 = "TFACTURASCOMPRAS26"
        base_currency_accounting_3 = "TFACTURASCOMPRAS27"
        tax_type_3 = "TFACTURASCOMPRAS28"
        tax_percentage_3 = "TFACTURASCOMPRAS29"
        tax_amount_currency_3 = "TFACTURASCOMPRAS30"
        amount_currency_accounting_3 = "TFACTURASCOMPRAS31"
        base_currency_4 = "TFACTURASCOMPRAS32"
        base_currency_accounting_4 = "TFACTURASCOMPRAS33"
        tax_type_4 = "TFACTURASCOMPRAS34"
        tax_percentage_4 = "TFACTURASCOMPRAS35"
        tax_amount_currency_4 = "TFACTURASCOMPRAS36"
        amount_currency_accounting_4 = "TFACTURASCOMPRAS37"
        total_invoice_currency = "TFACTURASCOMPRAS38"
        total_invoiceCurrencyAccounting = "TFACTURASCOMPRAS39"
        payment_mode = "TFACTURASCOMPRAS40"
        observations = "TFACTURASCOMPRAS41"
        retention_code = "TFACTURASCOMPRAS42"
        retention_percentage = "TFACTURASCOMPRAS43"
        accounted = "TFACTURASCOMPRAS56"
        retention_free = "TFACTURASCOMPRAS57"
        retention_base_currency = "TFACTURASCOMPRAS58"
        retention_base_internal = "TFACTURASCOMPRAS59"
        deductible_1 = "TFACTURASCOMPRAS60"
        deductible_2 = "TFACTURASCOMPRAS61"
        deductible_3 = "TFACTURASCOMPRAS62"
        deductible_4 = "TFACTURASCOMPRAS63"
        invoice_origin = "TFACTURASCOMPRAS64"
        amount_discount_internal = "TFACTURASCOMPRAS65"
        round_diff_internal = "TFACTURASCOMPRAS66"
        client_invoice_tri = "TFACTURASCOMPRAS67"  # TODO
        invoice_detailed = "TFACTURASCOMPRAS68"
        recharge_discount_tri = "TFACTURASCOMPRAS69"  # TODO
        series_sell_doc_tri = "TFACTURASCOMPRAS70"  # TODO
        sell_doc_tri = "TFACTURASCOMPRAS71"  # TODO
        sell_doc_tri_date = "TFACTURASCOMPRAS72"  # TODO
        invoice_type = "TFACTURASCOMPRAS73"
        declared = "TFACTURASCOMPRAS74"
        date_last_modified_after_declaration = "TFACTURASCOMPRAS75"
        provider_code_for_shipping_cost = "TFACTURASCOMPRAS76"
        invoice_date_provider_for_shipping_cost = "TFACTURASCOMPRAS77"
        invoice_number_provider_for_shipping_cost = "TFACTURASCOMPRAS78"
        rectifying_year = "TFACTURASCOMPRAS79"
        rectifying_series = "TFACTURASCOMPRAS80"
        rectifying_document_code = "TFACTURASCOMPRAS81"
        rectifying_invoice = "TFACTURASCOMPRAS82"
        declared_accumulated = "TFACTURASCOMPRAS87"
        date_operation = "TFACTURASCOMPRAS88"
        rectification_reason_code = "TFACTURASCOMPRAS89"
        rectification_reason_description = "TFACTURASCOMPRAS90"
        state_sii = "TFACTURASCOMPRAS91"
        invoice_class = "TFACTURASCOMPRAS92"
        invoice_state = "TFACTURASCOMPRAS93"
        liquidation_year = "TFACTURASCOMPRAS94"
        hash_sii = "TFACTURASCOMPRAS95"

    class VencimientosFacturasCompras:
        _tbl = "TVENCIMIENTOSFACTURASCOMPRAS"
        date_expire = "TVENCIMIENTOSFACTURASCOMPRAS1"
        ammount = "TVENCIMIENTOSFACTURASCOMPRAS2"
        ammount_internal = "TVENCIMIENTOSFACTURASCOMPRAS3"
        account_payment = "TVENCIMIENTOSFACTURASCOMPRAS4"
        state = "TVENCIMIENTOSFACTURASCOMPRAS5"
        year = "TVENCIMIENTOSFACTURASCOMPRAS6"
        series = "TVENCIMIENTOSFACTURASCOMPRAS7"
        document_code = "TVENCIMIENTOSFACTURASCOMPRAS8"
        payment_info = "TVENCIMIENTOSFACTURASCOMPRAS9"
        document_issued = "TVENCIMIENTOSFACTURASCOMPRAS10"
        payment_method_code = "TVENCIMIENTOSFACTURASCOMPRAS11"
        currency = "TVENCIMIENTOSFACTURASCOMPRAS12"
        provider_code = "TVENCIMIENTOSFACTURASCOMPRAS13"
        locked = "TVENCIMIENTOSFACTURASCOMPRAS14"
        invoice_code_provider = "TVENCIMIENTOSFACTURASCOMPRAS15"
        payment_origin = "TVENCIMIENTOSFACTURASCOMPRAS16"
        unequivocal = "TVENCIMIENTOSFACTURASCOMPRAS17"
        devolution = "TVENCIMIENTOSFACTURASCOMPRAS18"
        generation = "TVENCIMIENTOSFACTURASCOMPRAS19"
        rule_n34 = "TVENCIMIENTOSFACTURASCOMPRAS20"
        auto_numeric_line = "TVENCIMIENTOSFACTURASCOMPRAS21"
        locked_effect = "TVENCIMIENTOSFACTURASCOMPRAS22"
        comission_amount = "TVENCIMIENTOSFACTURASCOMPRAS23"
        comission_amount_internal = "TVENCIMIENTOSFACTURASCOMPRAS24"
        tax_amount = "TVENCIMIENTOSFACTURASCOMPRAS25"
        tax_amount_internal = "TVENCIMIENTOSFACTURASCOMPRAS26"
        invoice_code = "TVENCIMIENTOSFACTURASCOMPRAS27"
        invoice_code_buy = "TVENCIMIENTOSFACTURASCOMPRAS28"
        tax_type = "TVENCIMIENTOSFACTURASCOMPRAS29"
        send_pay_date = "TVENCIMIENTOSFACTURASCOMPRAS30"
        send_pay_number = "TVENCIMIENTOSFACTURASCOMPRAS31"
        index = "TVENCIMIENTOSFACTURASCOMPRAS32"
        invoice_id = "TVENCIMIENTOSFACTURASCOMPRAS33"
        declared = "TVENCIMIENTOSFACTURASCOMPRAS34"
        declared_omited = "TVENCIMIENTOSFACTURASCOMPRAS35"
        expiration_state = "TVENCIMIENTOSFACTURASCOMPRAS36"
        initial_unequivocal = "TVENCIMIENTOSFACTURASCOMPRAS37"  # TODO
        personal_code = "TVENCIMIENTOSFACTURASCOMPRAS38"
        anticipated = "TVENCIMIENTOSFACTURASCOMPRAS39"
        effect_supplied = "TVENCIMIENTOSFACTURASCOMPRAS40"

    class FacturasVentas:
        _tbl = "TFACTURASVENTAS"
        year = "TFACTURASVENTAS1"
        series = "TFACTURASVENTAS2"
        number = "TFACTURASVENTAS3"
        invoice_date = "TFACTURASVENTAS4"
        client_code = "TFACTURASVENTAS5"
        project_code = "TFACTURASVENTAS6"
        shipping_adress = "TFACTURASVENTAS7"
        shipping_zip_code = "TFACTURASVENTAS8"
        shipping_city = "TFACTURASVENTAS9"
        shipping_province = "TFACTURASVENTAS10"
        currency = "TFACTURASVENTAS11"
        invoice_accounted = "TFACTURASVENTAS12"
        shipping_cost_currency = "TFACTURASVENTAS13"
        shipping_cost_internal = "TFACTURASVENTAS14"
        other_charges_code = "TFACTURASVENTAS15"
        other_charges_amount_currency = "TFACTURASVENTAS16"
        other_charges_amount_internal = "TFACTURASVENTAS17"
        charges_currency = "TFACTURASVENTAS18"
        hold_back_percentage = "TFACTURASVENTAS19"
        hold_back_over_amount_currency = "TFACTURASVENTAS20"
        hold_back_over_amount_internal = "TFACTURASVENTAS21"
        in_concept_of = "TFACTURASVENTAS22"
        hold_back_amount = "TFACTURASVENTAS23"
        hold_back_counter_value = "TFACTURASVENTAS24"
        tax_base_1_currency = "TFACTURASVENTAS25"
        tax_base_1_currency_type = "TFACTURASVENTAS26"
        tax_base_1_currency_percentage = "TFACTURASVENTAS27"
        tax_base_1_currency_amount = "TFACTURASVENTAS28"
        tax_base_1_currency_passed_on_type_percentage = "TFACTURASVENTAS29"
        tax_base_1_currency_recharge_value = "TFACTURASVENTAS30"
        tax_base_2_currency = "TFACTURASVENTAS31"
        tax_base_2_currency_type = "TFACTURASVENTAS32"
        tax_base_2_currency_percentage = "TFACTURASVENTAS33"
        tax_base_2_currency_amount = "TFACTURASVENTAS34"
        tax_base_2_currency_passed_on_type_percentage = "TFACTURASVENTAS35"
        tax_base_2_currency_recharge_value = "TFACTURASVENTAS36"
        tax_base_3_currency = "TFACTURASVENTAS37"
        tax_base_3_currency_type = "TFACTURASVENTAS38"
        tax_base_3_currency_percentage = "TFACTURASVENTAS39"
        tax_base_3_currency_amount = "TFACTURASVENTAS40"
        tax_base_3_currency_passed_on_type_percentage = "TFACTURASVENTAS41"
        tax_base_3_currency_recharge_value = "TFACTURASVENTAS42"
        tax_base_4_currency = "TFACTURASVENTAS43"
        tax_base_4_currency_type = "TFACTURASVENTAS44"
        tax_base_4_currency_percentage = "TFACTURASVENTAS45"
        tax_base_4_currency_amount = "TFACTURASVENTAS46"
        tax_base_4_currency_passed_on_type_percentage = "TFACTURASVENTAS47"
        tax_base_4_currency_recharge_value = "TFACTURASVENTAS48"

        tax_base_1_internal = "TFACTURASVENTAS49"
        tax_base_1_internal_amount = "TFACTURASVENTAS50"
        tax_base_1_internal_passed_on_value = "TFACTURASVENTAS51"
        tax_base_2_internal = "TFACTURASVENTAS52"
        tax_base_2_internal_amount = "TFACTURASVENTAS53"
        tax_base_2_internal_passed_on_value = "TFACTURASVENTAS54"
        tax_base_3_internal = "TFACTURASVENTAS55"
        tax_base_3_internal_amount = "TFACTURASVENTAS56"
        tax_base_3_internal_passed_on_value = "TFACTURASVENTAS57"
        tax_base_4_internal = "TFACTURASVENTAS58"
        tax_base_4_internal_amount = "TFACTURASVENTAS59"
        tax_base_4_internal_passed_on_value = "TFACTURASVENTAS60"
        payment_method_code = "TFACTURASVENTAS63"
        payment_address = "TFACTURASVENTAS64"
        observations_invoicing = "TFACTURASVENTAS65"
        totals_tax_currency = "TFACTURASVENTAS66"
        total_tax_currency = "TFACTURASVENTAS68"
        total_invoice_currency = "TFACTURASVENTAS69"
        totals_tax_internal = "TFACTURASVENTAS70"
        totals_tax_internal = "TFACTURASVENTAS72"
        total_invoice_internal = "TFACTURASVENTAS73"
        gross_currency = "TFACTURASVENTAS76"
        gross_internal = "TFACTURASVENTAS78"
        other_charges_desc = "TFACTURASVENTAS82"
        payment_method_desc = "TFACTURASVENTAS84"
        observations_invoice = "TFACTURASVENTAS85"
        agent_code = "TFACTURASVENTAS87"
        correctedInvoiceCode = "TFACTURASVENTAS120"
        corrected_invoice_reason_code = "TFACTURASVENTAS121"
        corrected_invoice_reason_desc = "TFACTURASVENTAS122"
        corrected_invoice_panel_active = "TFACTURASVENTAS123"
        sii_state = "TFACTURASVENTAS125"
        invoice_class = "TFACTURASVENTAS126"

    class FacturasVentasCuentasIngresos:
        _tbl = "TFACTURASVENTASCUENTASINGRESOS"
        income_account = "TFACTURASVENTASCUENTASINGRESOS1"
        account_amount_currency = "TFACTURASVENTASCUENTASINGRESOS2"
        account_amount_internal = "TFACTURASVENTASCUENTASINGRESOS3"
        year = "TFACTURASVENTASCUENTASINGRESOS4"
        series = "TFACTURASVENTASCUENTASINGRESOS5"
        invoice = "TFACTURASVENTASCUENTASINGRESOS6"
        auto_numeric_line = "TFACTURASVENTASCUENTASINGRESOS7"
        cost_center = "TFACTURASVENTASCUENTASINGRESOS8"
        numeric_index = "TFACTURASVENTASCUENTASINGRESOS12"

    class FichaElementos:
        _tbl = "TFICHAELEMENTOS"
        code = "TFICHAELEMENTOS1"
        state = "TFICHAELEMENTOS2"
        currency_code = "TFICHAELEMENTOS3"
        article_code = "TFICHAELEMENTOS4"
        serial_number = "TFICHAELEMENTOS5"
        lot_number = "TFICHAELEMENTOS6"
        provider_code = "TFICHAELEMENTOS7"
        installer_code = "TFICHAELEMENTOS8"
        reserve = "TFICHAELEMENTOS9"
        final_client_code = "TFICHAELEMENTOS10"
        contact_person = "TFICHAELEMENTOS11"
        contact_phone = "TFICHAELEMENTOS12"
        reference = "TFICHAELEMENTOS13"
        project_code = "TFICHAELEMENTOS14"
        project_desc = "TFICHAELEMENTOS15"
        location = "TFICHAELEMENTOS16"
        units = "TFICHAELEMENTOS17"
        sell_price = "TFICHAELEMENTOS18"
        sell_price_internal = "TFICHAELEMENTOS19"
        amount = "TFICHAELEMENTOS20"
        amount_internal = "TFICHAELEMENTOS21"
        sell_date = "TFICHAELEMENTOS22"
        warranty_start_date = "TFICHAELEMENTOS23"
        installation_date = "TFICHAELEMENTOS24"
        warranty_end_buzzer = "TFICHAELEMENTOS25"
        setup_date = "TFICHAELEMENTOS26"
        reserve_5 = "TFICHAELEMENTOS27"
        reserve_6 = "TFICHAELEMENTOS28"
        reserve_7 = "TFICHAELEMENTOS29"
        reserve_8 = "TFICHAELEMENTOS30"
        dont_offer_maintenance = "TFICHAELEMENTOS31"
        dont_offer_maintenance_date = "TFICHAELEMENTOS32"
        comments = "TFICHAELEMENTOS33"
        reserve_10 = "TFICHAELEMENTOS34"
        observations = "TFICHAELEMENTOS35"
        final_client_name = "TFICHAELEMENTOS36"
        mailing_code = "TFICHAELEMENTOS37"
        discount = "TFICHAELEMENTOS38"
        reserve_9 = "TFICHAELEMENTOS39"
        difficulty_level = "TFICHAELEMENTOS40"
        project_sub_code = "TFICHAELEMENTOS41"
        article_description = "TFICHAELEMENTOS42"
        free_field_1 = "TFICHAELEMENTOS43"
        free_field_2 = "TFICHAELEMENTOS44"
        free_field_3 = "TFICHAELEMENTOS45"
        fire_extinguishers = "TFICHAELEMENTOS46"
        user = "TFICHAELEMENTOS47"
        free_field_4 = "TFICHAELEMENTOS48"
        free_field_5 = "TFICHAELEMENTOS49"
        free_field_6 = "TFICHAELEMENTOS50"
        free_field_7 = "TFICHAELEMENTOS51"
        free_field_8 = "TFICHAELEMENTOS52"
        free_field_9 = "TFICHAELEMENTOS53"
        free_field_10 = "TFICHAELEMENTOS54"
        identification = "TFICHAELEMENTOS55"
        component = "TFICHAELEMENTOS56"
        main_element = "TFICHAELEMENTOS57"
        element_tipology = "TFICHAELEMENTOS58"
        is_own_element = "TFICHAELEMENTOS59"
        belongs_to_final_client = "TFICHAELEMENTOS60"
        element_classification = "TFICHAELEMENTOS61"
        main_element_of_project = "TFICHAELEMENTOS62"
        current_km = "TFICHAELEMENTOS63"
        hidden_element = "TFICHAELEMENTOS64"
        street = "TFICHAELEMENTOS65"
        zip_code = "TFICHAELEMENTOS66"
        city = "TFICHAELEMENTOS67"
        province = "TFICHAELEMENTOS68"
        free_field_11 = "TFICHAELEMENTOS69"
        free_field_12 = "TFICHAELEMENTOS70"
        free_field_13 = "TFICHAELEMENTOS71"
        free_field_14 = "TFICHAELEMENTOS72"
        free_field_15 = "TFICHAELEMENTOS73"
        free_field_16 = "TFICHAELEMENTOS74"
        free_field_17 = "TFICHAELEMENTOS75"
        maintenance_group = "TFICHAELEMENTOS76"
        free_field_18 = "TFICHAELEMENTOS77"
        special_treatment_code = "TFICHAELEMENTOS78"
        hidden_element_software = "TFICHAELEMENTOS79"
        hidden_element_hardware = "TFICHAELEMENTOS80"
        with_contract = "TFICHAELEMENTOS81"
        character = "TFICHAELEMENTOS82"
        department_contact_person = "TFICHAELEMENTOS83"
        contact_person_2 = "TFICHAELEMENTOS84"
        phone2 = "TFICHAELEMENTOS85"
        department_contact_person_2 = "TFICHAELEMENTOS86"
        installer_code_2 = "TFICHAELEMENTOS87"
        installation_date_2_instruction = "TFICHAELEMENTOS88"
        installation_date_3_instruction = "TFICHAELEMENTOS89"
        maintenance_contract_date_start = "TFICHAELEMENTOS90"
        maintenance_contract_date_end = "TFICHAELEMENTOS91"
        company = "TFICHAELEMENTOS92"
        headquarter = "TFICHAELEMENTOS93"
        calca = "TFICHAELEMENTOS94"

    class Horas:
        _tbl = "THORAS"
        code = "THORAS1"
        desc = "THORAS2"
        consider_as_time = "THORAS3"
        normal_hour = "THORAS4"
        extra_hour = "THORAS5"
        impute_to_article = "THORAS6"
        impute_prop_time = "THORAS7"
        impute_prop_amount = "THORAS8"
        impute_only_project_units = "THORAS9"
        family_code = "THORAS10"

    class Matriculas:
        _tbl = "TMATRICULAS"
        code = "TMATRICULAS1"
        license_plate = "TMATRICULAS2"
        observations = "TMATRICULAS3"
        is_own_vehicle = "TMATRICULAS4"
        carrier_code = "TMATRICULAS5"
        price_rate_1 = "TMATRICULAS6"
        price_rate_1_internal = "TMATRICULAS7"
        price_rate_2 = "TMATRICULAS8"
        price_rate_2_internal = "TMATRICULAS9"
        price_rate_3 = "TMATRICULAS10"
        price_rate_3_internal = "TMATRICULAS11"
        price_rate_4 = "TMATRICULAS12"
        price_rate_4_internal = "TMATRICULAS13"
        currency = "TMATRICULAS14"
        default_driver = "TMATRICULAS15"
        license_plate_trailer = "TMATRICULAS16"
        seal_number = "TMATRICULAS17"
        country_code = "TMATRICULAS18"
        tare = "TMATRICULAS19"
        
    class Nominas:
        _tbl = "TNOMINAS"
        document_code = "TNOMINAS1"
        individual_entry = "TNOMINAS27"

    class NumeracionAvisos:
        _tbl = "TNUMERACIONAVISOS"
        last_code_used = "TNUMERACIONAVISOS1"
        auto_code_enabled = "TNUMERACIONAVISOS2"
        name = "TNUMERACIONAVISOS3"
        sell_doc_series = "TNUMERACIONAVISOS4"
        print_format = "TNUMERACIONAVISOS5"
        create_checklist = "TNUMERACIONAVISOS6"
        base_element = "TNUMERACIONAVISOS7"
        worker_force_do_all_tasks = "TNUMERACIONAVISOS8"
        invoice_type_material = "TNUMERACIONAVISOS9"
        invoice_type_hr = "TNUMERACIONAVISOS10"

    class Obras:
        _tbl = "TOBRAS"
        code = "TOBRAS1"
        name = "TOBRAS2"
        client = "TOBRAS3"
        situation_if_relevant = "TOBRAS4"
        status = "TOBRAS5"
        zip_code = "TOBRAS6"
        city = "TOBRAS7"
        province = "TOBRAS8"
        country = "TOBRAS9"
        budget_code = "TOBRAS10"
        target_dates = "TOBRAS11"
        in_charge = "TOBRAS12"
        comission_agent_code = "TOBRAS13"
        discount_table_code = "TOBRAS14"
        tax_passed_on_type_code = "TOBRAS15"
        assign_direct_expenses_since_invoice_enter = "TOBRAS16"
        globally_to_projecst = "TOBRAS17"
        indicate_budget_heading = "TOBRAS18"
        contract_repair_maintenance = "TOBRAS19"
        repair_contract_start = "TOBRAS20"
        repair_contract_end = "TOBRAS21"
        notify_user = "TOBRAS22"
        user_code = "TOBRAS23"
        days_anticipation = "TOBRAS24"
        free_field_1 = "TOBRAS25"
        free_field_2 = "TOBRAS26"
        free_field_3 = "TOBRAS27"
        show = "TOBRAS28"
        indicate_only_on_show = "TOBRAS29"
        observations = "TOBRAS30"
        budget_series = "TOBRAS31"
        accounting_total_budget = "TOBRAS32"
        accounting_certificate = "TOBRAS33"
        accounting_difference = "TOBRAS34"
        certificate_percentage = "TOBRAS35"
        cost_center_code = "TOBRAS36"
        holidays_table_code = "TOBRAS37"
        payment_method = "TOBRAS38"
        multiple_clientes = "TOBRAS39"
        project_type = "TOBRAS40"
        project_group_code = "TOBRAS41"
        shipping_cost_zone = "TOBRAS42"
        warehouse_code = "TOBRAS43"
        contact_person = "TOBRAS44"
        phone = "TOBRAS45"
        fax = "TOBRAS46"
        mobile = "TOBRAS47"
        project_date_start = "TOBRAS48"
        project_date_end = "TOBRAS49"
        necessary_folders = "TOBRAS50"
        project_planification_code = "TOBRAS51"
        iso_year = "TOBRAS52"
        iso_city = "TOBRAS53"
        iso_work_type = "TOBRAS54"
        iso_co_relative_number = "TOBRAS55"
        leave_reason = "TOBRAS56"
        certification_model_calc_1 = "TOBRAS57"
        certification_model_calc_2 = "TOBRAS58"
        pgc_of_on_going_project = "TOBRAS59"
        observations_2 = "TOBRAS60"
        pending_installation_material_cost = "TOBRAS61"
        free_field_7 = "TOBRAS62"
        free_field_8 = "TOBRAS63"
        free_field_9 = "TOBRAS64"
        free_field_10 = "TOBRAS65"
        free_field_11 = "TOBRAS66"
        pgc_sells = "TOBRAS67"
        project_payment_day_1 = "TOBRAS68"
        project_payment_day_2 = "TOBRAS69"
        project_payment_day_3 = "TOBRAS70"
        month_dont_pay = "TOBRAS71"
        zone_position = "TOBRAS72"
        retention_code = "TOBRAS73"
        retention_claim_date = "TOBRAS74"
        retention_claimed = "TOBRAS75"
        retention_charged = "TOBRAS76"
        retention_devolution_conditions = "TOBRAS77"
        field_released_1 = "TOBRAS78"
        client_shedule = "TOBRAS79"
        ccc_1 = "TOBRAS80"
        free_field_4 = "TOBRAS81"
        free_field_5 = "TOBRAS82"
        free_field_6 = "TOBRAS83"
        country_code = "TOBRAS84"
        correction_factor = "TOBRAS85"
        project_date_open = "TOBRAS86"
        project_date_close = "TOBRAS87"
        project_boss = "TOBRAS88"
        team_boss = "TOBRAS89"
        mailing_code = "TOBRAS90"
        pending_documentation_date = "TOBRAS91"
        pending_documentation_observations = "TOBRAS92"
        production_date = "TOBRAS93"
        production_observations = "TOBRAS94"
        mapping_pending_date = "TOBRAS95"
        mapping_pending_observations = "TOBRAS96"
        invoicing_pending_date = "TOBRAS97"
        invoicing_pending_observations = "TOBRAS98"
        charging_pending_date = "TOBRAS99"
        charging_pending_observations = "TOBRAS100"
        charged_date = "TOBRAS101"
        charged_observations = "TOBRAS102"
        leaving_location = "TOBRAS103"
        internal = "TOBRAS104"
        gps_lat = "TOBRAS105"
        gps_long = "TOBRAS106"
        gps_positioning = "TOBRAS107"
        gps_positioning_data = "TOBRAS108"
        technical_1 = "TOBRAS109"
        technical_2 = "TOBRAS110"
        technical_3 = "TOBRAS111"
        technical_4 = "TOBRAS112"
        technical_5 = "TOBRAS113"
        rao_entry_date = "TOBRAS114"
        rao_study_technical = "TOBRAS115"
        study_by_percentage = "TOBRAS116"
        theorical_cost_price = "TOBRAS117"
        iban_1 = "TOBRAS118"
        bic_code = "TOBRAS119"
        discount_table_pp_code = "TOBRAS120"
        payment_for_periodicals = "TOBRAS121"
        number_of_hours_hirded_hour_bag = "TOBRAS122"
        manager_organ = "TOBRAS1123"
        process_unit = "TOBRAS124"
        accounting_office = "TOBRAS125"
        capable_organ = "TOBRAS126"
        assigned_code = "TOBRAS127"
        dossier_number = "TOBRAS128"
        in_charge_delegation_code = "TOBRAS129"
        publish_pi_connect = "TOBRAS130"
        email = "TOBRAS131"
        reserve_1 = "TOBRAS132"
        reserve_2 = "TOBRAS133"
        allow_web_access = "TOBRAS134"
        property_situation = "TOBRAS135"
        land_registry_reference = "TOBRAS136"
        gender = "TOBRAS137"
        nif = "TOBRAS138"
        age = "TOBRAS139"
        update_date = "TOBRAS140"
        police_number = "TOBRAS141"

    class PartesManuales:
        _tbl = "TPARTESMANUALES"
        code = "TPARTESMANUALES1"
        am_pm = "TPARTESMANUALES21"
        currency = "TPARTESMANUALES22"
        worker = "TPARTESMANUALES23"
        date = "TPARTESMANUALES24"

    class PartesManualesNumeracion:
        _tbl = "TPARTESMANUALESNUMERACION"
        last_code = "TPARTESMANUALES1"

    class PersonalPosesionHerramientasCabecera:
        _tbl = "TPERSONALPOSESIONHERRAMIENTASCABECERA"
        worker_code = "TPERSONALPOSESIONHERRAMIENTASCABECERA1"
        worker_name = "TPERSONALPOSESIONHERRAMIENTASCABECERA2"
        currency = "TPERSONALPOSESIONHERRAMIENTASCABECERA3"

    class PersonalPosesionHerramientas:
        _tbl = "TPERSONALPOSESIONHERRAMIENTAS"
        tool_code = "TPERSONALPOSESIONHERRAMIENTAS1"
        units = "TPERSONALPOSESIONHERRAMIENTAS2"
        delivery_date = "TPERSONALPOSESIONHERRAMIENTAS3"
        value = "TPERSONALPOSESIONHERRAMIENTAS4"
        worker_code = "TPERSONALPOSESIONHERRAMIENTAS5"
        value_currency = "TPERSONALPOSESIONHERRAMIENTAS6"
        auto_numeric_line = "TPERSONALPOSESIONHERRAMIENTAS7"
        observations = "TPERSONALPOSESIONHERRAMIENTAS8"
        serial_nr = "TPERSONALPOSESIONHERRAMIENTAS9"
        return_date = "TPERSONALPOSESIONHERRAMIENTAS10"
        numeric_index = "TPERSONALPOSESIONHERRAMIENTAS11"
        time_delivery = "TPERSONALPOSESIONHERRAMIENTAS12"
        time_return = "TPERSONALPOSESIONHERRAMIENTAS13"

    class TraspasosHerramientasNumeracion:
        _tbl = "TTRASPASOSHERRAMIENTASNUMERACION"
        last_code = "TTRASPASOSHERRAMIENTASNUMERACION1"

    class PersonalTraspasoHerramientasCabecera:
        _tbl = "TPERSONALTRASPASOHERRAMIENTASCABECERA"
        code = "TPERSONALTRASPASOHERRAMIENTASCABECERA1"

    class PersonalTraspasoHerramientas:
        _tbl = "TPERSONALTRASPASOHERRAMIENTAS"
        date = "TPERSONALTRASPASOHERRAMIENTAS1"
        tool_code = "TPERSONALTRASPASOHERRAMIENTAS2"
        serial_nr = "TPERSONALTRASPASOHERRAMIENTAS3"
        from_worker_code = "TPERSONALTRASPASOHERRAMIENTAS4"
        to_worker_code = "TPERSONALTRASPASOHERRAMIENTAS5"
        observations = "TPERSONALTRASPASOHERRAMIENTAS6"
        part_code_index = "TPERSONALTRASPASOHERRAMIENTAS7"
        auto_numeric_line = "TPERSONALTRASPASOHERRAMIENTAS8"
        numeric_index = "TPERSONALTRASPASOHERRAMIENTAS9"
        timestamp = "TPERSONALTRASPASOHERRAMIENTAS10"

    class Pedidos:
        _tbl = "TPEDIDOS"
        our_order = "TPEDIDOS1"
        date = "TPEDIDOS2"
        your_order = "TPEDIDOS3"
        delivery_date = "TPEDIDOS4"
        state = "TPEDIDOS5"
        currency = "TPEDIDOS6"
        client_code = "TPEDIDOS9"
        project_code = "TPEDIDOS10"
        ordered_by = "TPEDIDOS11"
        client_street = "TPEDIDOS13"
        client_zip_code = "TPEDIDOS14"
        client_city = "TPEDIDOS15"
        client_province = "TPEDIDOS16"
        client_country = "TPEDIDOS17"
        payment_code = "TPEDIDOS18"
        comission_agent = "TPEDIDOS19"
        priority = "TPEDIDOS20"
        up_to_date = "TPEDIDOS22"
        send_when_complete = "TPEDIDOS24"
        send_in_next_order = "TPEDIDOS25"
        leave_it_partial_served = "TPEDIDOS26"
        leave_it_closed = "TPEDIDOS27"
        observations = "TPEDIDOS28"
        shipping_medium = "TPEDIDOS29"
        shipping_cost = "TPEDIDOS30"
        amount = "TPEDIDOS32"
        price_type = "TPEDIDOS33"
        auth_id = "TPEDIDOS34"
        margin = "TPEDIDOS35"
        margin_percent = "TPEDIDOS36"
        cost_accounting = "TPEDIDOS37"
        cost_document = "TPEDIDOS38"
        discount = "TPEDIDOS39"
        total_accounting = "TPEDIDOS40"
        total_currency = "TPEDIDOS41"
        price_accounting = "TPEDIDOS42"
        price_currency = "TPEDIDOS43"
        base_accounting_1 = "TPEDIDOS48"
        base_currency_1 = "TPEDIDOS49"
        tax_type_code_1 = "TPEDIDOS50"
        tax_percentage_1 = "TPEDIDOS51"
        tax_total_accounting_1 = "TPEDIDOS52"
        tax_total_currency_1 = "TPEDIDOS53"
        tax_total_rechargee_equivalence_percentage_1 = "TPEDIDOS54"
        tax_total_rechargee_equivalence_accounting_1 = "TPEDIDOS55"
        tax_total_rechargee_equivalence_currency_1 = "TPEDIDOS56"
        base_accounting_2 = "TPEDIDOS57"
        base_currency_2 = "TPEDIDOS58"
        tax_type_code_2 = "TPEDIDOS59"
        tax_percentage_2 = "TPEDIDOS60"
        tax_total_accounting_2 = "TPEDIDOS61"
        tax_total_currency_2 = "TPEDIDOS62"
        tax_total_rechargee_equivalence_percentage_2 = "TPEDIDOS63"
        tax_total_rechargee_equivalence_accounting_2 = "TPEDIDOS64"
        tax_total_rechargee_equivalence_currency_2 = "TPEDIDOS65"
        base_accounting_3 = "TPEDIDOS66"
        base_currency_3 = "TPEDIDOS67"
        tax_type_code_3 = "TPEDIDOS68"
        tax_percentage_3 = "TPEDIDOS69"
        tax_total_accounting_3 = "TPEDIDOS70"
        tax_total_currency_3 = "TPEDIDOS71"
        tax_total_rechargee_equivalence_percentage_3 = "TPEDIDOS72"
        tax_total_rechargee_equivalence_accounting_3 = "TPEDIDOS73"
        tax_total_rechargee_equivalence_currency_3 = "TPEDIDOS74"
        base_accounting_4 = "TPEDIDOS75"
        base_currency_4 = "TPEDIDOS76"
        tax_type_code_4 = "TPEDIDOS77"
        tax_percentage_4 = "TPEDIDOS78"
        tax_total_accounting_4 = "TPEDIDOS79"
        tax_total_currency_4 = "TPEDIDOS80"
        tax_total_rechargee_equivalence_percentage_4 = "TPEDIDOS81"
        tax_total_rechargee_equivalence_accounting_4 = "TPEDIDOS82"
        tax_total_rechargee_equivalence_currency_4 = "TPEDIDOS83"
        language_code = "TPEDIDOS84"
        warehouse_code_exit = "TPEDIDOS86"
        client_nif = "TPEDIDOS87"
        client_phone = "TPEDIDOS88"
        contact_phone = "TPEDIDOS89"
        client_name = "TPEDIDOS90"
        client_with_record = "TPEDIDOS92"
        document_type = "TPEDIDOS99"
        rate_name = "TPEDIDOS102"
        order_time = "TPEDIDOS104"
        user = "TPEDIDOS122"
        contact_email = "TPEDIDOS124"
        sync_b2b = "TPEDIDOS129"
        purchase_order_placed = "TPEDIDOS138"
        logistic_status = "TPEDIDOS152"

    class ValoresPedidos:
        _tbl = "TVALORESPEDIDOS"
        line_type = "TVALORESPEDIDOS1"
        article_code = "TVALORESPEDIDOS2"
        article_desc = "TVALORESPEDIDOS3"
        count = "TVALORESPEDIDOS7"
        count_billable = "TVALORESPEDIDOS8"
        count_served = "TVALORESPEDIDOS9"
        count_remaining = "TVALORESPEDIDOS10"
        unit_price_accounting = "TVALORESPEDIDOS11"
        unit_price = "TVALORESPEDIDOS12"
        pvp_internal = "TVALORESPEDIDOS13"
        discount = "TVALORESPEDIDOS14"
        amount_accounting = "TVALORESPEDIDOS15"
        amount = "TVALORESPEDIDOS16"
        line_type_char = "TVALORESPEDIDOS17"
        tax_code = "TVALORESPEDIDOS18"
        order_code = "TVALORESPEDIDOS19"
        sheet = "TVALORESPEDIDOS20"
        # realmente no tenemos claro para que es este campo lo estamos insertando como 2000000 +1 para cada linea del pedido
        order_line_index_12 = "TVALORESPEDIDOS21"
        price_tax_included = "TVALORESPEDIDOS22"
        budget_header = "TVALORESPEDIDOS23"
        equivalence_surcharge_percentage = "TVALORESPEDIDOS24"
        tax_percentage = "TVALORESPEDIDOS25"
        price_tax_included_accounting = "TVALORESPEDIDOS26"
        order_line_index = "TVALORESPEDIDOS27"
        count_x_project_units = "TVALORESPEDIDOS29"
        cost_accounting = "TVALORESPEDIDOS30"
        cost = "TVALORESPEDIDOS31"
        margin_percentage = "TVALORESPEDIDOS32"
        stock_current_reservation = "TVALORESPEDIDOS33"
        stock_future_reservation = "TVALORESPEDIDOS34"
        parts_ordered = "TVALORESPEDIDOS38"
        parts_x_project_units = "TVALORESPEDIDOS39"
        parts_served = "TVALORESPEDIDOS40"
        parts_pending = "TVALORESPEDIDOS41"
        parts_stock_current_reservation = "TVALORESPEDIDOS42"
        parts_stock_future_reservation = "TVALORESPEDIDOS43"
        client_code = "TVALORESPEDIDOS44"
        document_date = "TVALORESPEDIDOS45"
        currency = "TVALORESPEDIDOS46"
        project_code = "TVALORESPEDIDOS47"
        discount_fast_payment = "TVALORESPEDIDOS48"
        observations = "TVALORESPEDIDOS50"
        price_original = "TVALORESPEDIDOS51"
        dimension_height = "TVALORESPEDIDOS52"
        dimension_width = "TVALORESPEDIDOS53"
        dimension_thickness = "TVALORESPEDIDOS54"
        dimension_swing = "TVALORESPEDIDOS55"
        uid = "TVALORESPEDIDOS61"
        dimension_weight_for_rate = "TVALORESPEDIDOS62"
        numerator = "TVALORESPEDIDOS65"

    class PedidosNumeracion:
        _tbl = "TPEDIDOSNUMERACION"
        last_code_used = "TPEDIDOSNUMERACION1"

    class PedidosProvedoreesContador:
        _tbl = "TPEDIDOSAPROVEEDORESCONTADOR"
        last_order_number = "TPEDIDOSAPROVEEDORESCONTADOR2"
        last_discount_number = "TPEDIDOSAPROVEEDORESCONTADOR4"
        soc = "TPEDIDOSAPROVEEDORESCONTADOR5"

    class PedidosProveedores:
        _tbl = "TPEDIDOSAPROVEEDORES"
        document_number = "TPEDIDOSAPROVEEDORES1"
        document_date = "TPEDIDOSAPROVEEDORES2"
        order_priority = "TPEDIDOSAPROVEEDORES4"
        provider_code = "TPEDIDOSAPROVEEDORES5"
        order_state = "TPEDIDOSAPROVEEDORES6"
        order_send_address = "TPEDIDOSAPROVEEDORES7"
        language_code = "TPEDIDOSAPROVEEDORES8"
        currencies = "TPEDIDOSAPROVEEDORES9"
        contact_person = "TPEDIDOSAPROVEEDORES10"
        project_code = "TPEDIDOSAPROVEEDORES11"
        discount = "TPEDIDOSAPROVEEDORES12"
        delegation_who_orders_code = "TPEDIDOSAPROVEEDORES13"
        person_who_orders_code = "TPEDIDOSAPROVEEDORES14"
        adjust_auto_min_order = "TPEDIDOSAPROVEEDORES15"
        payment_method_code = "TPEDIDOSAPROVEEDORES22"
        authorization_id = "TPEDIDOSAPROVEEDORES24"
        observations = "TPEDIDOSAPROVEEDORES25"
        internal_comments = "TPEDIDOSAPROVEEDORES26"
        total_order = "TPEDIDOSAPROVEEDORES28"
        warehouse_code = "TPEDIDOSAPROVEEDORES30"
        document_type = "TPEDIDOSAPROVEEDORES31"
        alert_code = "TPEDIDOSAPROVEEDORES60"
        free_field_1 = "TPEDIDOSAPROVEEDORES96"
        free_field_2 = "TPEDIDOSAPROVEEDORES97"
        free_field_3 = "TPEDIDOSAPROVEEDORES98"

    class ValoresPedidosProveedores:
        _tbl = "TVALORESPEDIDOSAPROVEEDORES"
        ref = "TVALORESPEDIDOSAPROVEEDORES1"
        desc = "TVALORESPEDIDOSAPROVEEDORES2"
        unit = "TVALORESPEDIDOSAPROVEEDORES3"
        count = "TVALORESPEDIDOSAPROVEEDORES4"
        price = "TVALORESPEDIDOSAPROVEEDORES5"
        price_currency_internal = "TVALORESPEDIDOSAPROVEEDORES6"  # TODO
        discount_percentage = "TVALORESPEDIDOSAPROVEEDORES7"
        amount = "TVALORESPEDIDOSAPROVEEDORES8"
        amount_currency_internal = "TVALORESPEDIDOSAPROVEEDORES9"
        served = "TVALORESPEDIDOSAPROVEEDORES10"
        pending = "TVALORESPEDIDOSAPROVEEDORES11"
        order_code = "TVALORESPEDIDOSAPROVEEDORES12"
        internal_info = "TVALORESPEDIDOSAPROVEEDORES13"
        amount_billable = "TVALORESPEDIDOSAPROVEEDORES14"
        price_type = "TVALORESPEDIDOSAPROVEEDORES15"
        net_price = "TVALORESPEDIDOSAPROVEEDORES16"
        net_price_currency_internal = "TVALORESPEDIDOSAPROVEEDORES17"  # TODO
        auto_numeric_line = "TVALORESPEDIDOSAPROVEEDORES18"
        reference_article_provider = "TVALORESPEDIDOSAPROVEEDORES19"
        order_line_id = "TVALORESPEDIDOSAPROVEEDORES20"
        observations = "TVALORESPEDIDOSAPROVEEDORES21"
        document_type = "TVALORESPEDIDOSAPROVEEDORES22"
        units_served = "TVALORESPEDIDOSAPROVEEDORES24"
        units_pending = "TVALORESPEDIDOSAPROVEEDORES25"
        numeric_index = "TVALORESPEDIDOSAPROVEEDORES35"
        production_series = "TVALORESPEDIDOSAPROVEEDORES36"
        production_number = "TVALORESPEDIDOSAPROVEEDORES37"
        uid = "TVALORESPEDIDOSAPROVEEDORES38"
        task = "TVALORESPEDIDOSAPROVEEDORES39"
        task_name = "TVALORESPEDIDOSAPROVEEDORES40"

    class PreciosFuturos:
        _tbl = "TPRECIOSFUTUROS"
        start_date = "TPRECIOSFUTUROS4"
        id = "TPRECIOSFUTUROS7"

    class Presupuestos:
        _tbl = "TPRESUPUESTOS"
        series = "TPRESUPUESTOS1"
        code = "TPRESUPUESTOS2"
        creation_date = "TPRESUPUESTOS3"
        client_code = "TPRESUPUESTOS4"
        client_name = "TPRESUPUESTOS5"
        project = "TPRESUPUESTOS12"
        state = "TPRESUPUESTOS14"  # Terminado Sustituido Aceptado No aceptado Pendiente contestar En ejecucion
        state_resolution = "TPRESUPUESTOS15"
        Observations = "TPRESUPUESTOS17"
        description = "TPRESUPUESTOS18"
        margin = "TPRESUPUESTOS47"
        amount_total = "TPRESUPUESTOS52"  # Total contablidad
        amount_total_currency = "TPRESUPUESTOS53"  # Total Divisa
        amount = "TPRESUPUESTOS54"
        base_amount_1 = "TPRESUPUESTOS60"
        payment_code = "TPRESUPUESTOS105"
        emitter_name = "TPRESUPUESTOS106"
        delegation_code = "TPRESUPUESTOS108"
        user = "TPRESUPUESTOS117"
        emitter_code = "TPRESUPUESTOS147"

    class PrevisionesCobrosPagos:
        _tbl = "TPREVISIONESCOBROSPAGOS"
        registry_number = "TPREVISIONESCOBROSPAGOS1"
        denomination = "TPREVISIONESCOBROSPAGOS2"
        currency = "TPREVISIONESCOBROSPAGOS3"
        payment_in_type = "TPREVISIONESCOBROSPAGOS4"
        payment_out_type = "TPREVISIONESCOBROSPAGOS5"
        auto_periodicity = "TPREVISIONESCOBROSPAGOS6"
        currency_amount = "TPREVISIONESCOBROSPAGOS7"
        account_number_billing_payment = "TPREVISIONESCOBROSPAGOS8"
        expiration_date_1 = "TPREVISIONESCOBROSPAGOS9"
        periodicity_daily = "TPREVISIONESCOBROSPAGOS10"
        periodicity_bi_weekly = "TPREVISIONESCOBROSPAGOS11"
        periodicity_quarterly = "TPREVISIONESCOBROSPAGOS12"
        periodicity_annual = "TPREVISIONESCOBROSPAGOS13"
        periodicity_weekly = "TPREVISIONESCOBROSPAGOS14"
        periodicity_monthly = "TPREVISIONESCOBROSPAGOS15"
        periodicity_bi_annual = "TPREVISIONESCOBROSPAGOS16"
        periodicity_every_x = "TPREVISIONESCOBROSPAGOS17"
        periodicity_days = "TPREVISIONESCOBROSPAGOS18"
        set_manual_periodicity = "TPREVISIONESCOBROSPAGOS19"
        delete_automatically = "TPREVISIONESCOBROSPAGOS20"
        delete_automatically_days = "TPREVISIONESCOBROSPAGOS21"
        delete_manual = "TPREVISIONESCOBROSPAGOS22"
        notify_user = "TPREVISIONESCOBROSPAGOS23"
        user_code = "TPREVISIONESCOBROSPAGOS24"
        notify_accounting = "TPREVISIONESCOBROSPAGOS25"
        account_code = "TPREVISIONESCOBROSPAGOS26"
        notify_management = "TPREVISIONESCOBROSPAGOS27"
        client_code = "TPREVISIONESCOBROSPAGOS28"
        provider_code = "TPREVISIONESCOBROSPAGOS29"
        import_currency_accounting = "TPREVISIONESCOBROSPAGOS30"
        adjust_on_month_end = "TPREVISIONESCOBROSPAGOS31"
        next_expiration_date = "TPREVISIONESCOBROSPAGOS32"

    class ValoresPrevisionesCobrosPagos:
        _tbl = "TVALORESPREVISIONESCOBROSPAGOS"
        date = "TVALORESPREVISIONESCOBROSPAGOS1"
        amount = "TVALORESPREVISIONESCOBROSPAGOS2"
        amount_contability = "TVALORESPREVISIONESCOBROSPAGOS3"
        acccount_charge_payment = "TVALORESPREVISIONESCOBROSPAGOS4"
        registry_number = "TVALORESPREVISIONESCOBROSPAGOS5"
        auto_numeric_line = "TVALORESPREVISIONESCOBROSPAGOS6"
        numeric_index = "TVALORESPREVISIONESCOBROSPAGOS7"

    class Proveedores:
        _tbl = "TPROVEEDORES"
        code = "TPROVEEDORES1"
        name = "TPROVEEDORES2"
        accounting_account = "TPROVEEDORES3"
        name_usal = "TPROVEEDORES4"
        fiscal_address = "TPROVEEDORES5"
        zip_code = "TPROVEEDORES6"
        city = "TPROVEEDORES7"
        province = "TPROVEEDORES8"
        country = "TPROVEEDORES9"
        phone = "TPROVEEDORES10"
        fax = "TPROVEEDORES11"
        web = "TPROVEEDORES12"
        email = "TPROVEEDORES13"
        nif = "TPROVEEDORES14"
        currency = "TPROVEEDORES15"
        group_code = "TPROVEEDORES19"
        observations = "TPROVEEDORES26"
        type = "TPROVEEDORES40"
        payment_mode_code = "TPROVEEDORES47"
        usual_income_account = "TPROVEEDORES52"
        mailing_code = "TPROVEEDORES133"

    class ValoresPreciosFuturos:
        _tbl = "TVALORESPRECIOSFUTUROS"
        article_ref = "TVALORESPRECIOSFUTUROS1"
        family_code = "TVALORESPRECIOSFUTUROS2"
        previous_price = "TVALORESPRECIOSFUTUROS3"
        currency = "TVALORESPRECIOSFUTUROS5"
        percentage_variable = "TVALORESPRECIOSFUTUROS7"
        final_price = "TVALORESPRECIOSFUTUROS8"
        future_prices_id = "TVALORESPRECIOSFUTUROS11"

    class VencimientosFacturasVentas:
        _tbl = "TVENCIMIENTOSFACTURASVENTAS"
        expire_date = "TVENCIMIENTOSFACTURASVENTAS1"
        amount_currency = "TVENCIMIENTOSFACTURASVENTAS2"
        account_to_charge = "TVENCIMIENTOSFACTURASVENTAS3"
        state = "TVENCIMIENTOSFACTURASVENTAS4"
        invoice_number = "TVENCIMIENTOSFACTURASVENTAS5"
        ammount_internal = "TVENCIMIENTOSFACTURASVENTAS6"
        series = "TVENCIMIENTOSFACTURASVENTAS7"
        year = "TVENCIMIENTOSFACTURASVENTAS8"
        charge_date = "TVENCIMIENTOSFACTURASVENTAS9"
        collection_number = "TVENCIMIENTOSFACTURASVENTAS10"
        no_idea_1 = "TVENCIMIENTOSFACTURASVENTAS11"  # TODO revisar
        no_idea_2 = "TVENCIMIENTOSFACTURASVENTAS12"  # TODO revisar
        no_idea_3 = "TVENCIMIENTOSFACTURASVENTAS13"  # TODO revisar
        client_code = "TVENCIMIENTOSFACTURASVENTAS14"
        currency = "TVENCIMIENTOSFACTURASVENTAS15"
        type = "TVENCIMIENTOSFACTURASVENTAS16"
        sell_document_code = "TVENCIMIENTOSFACTURASVENTAS18"
        charge_code = "TVENCIMIENTOSFACTURASVENTAS20"
        payment_method = "TVENCIMIENTOSFACTURASVENTAS29"
        invoice_expire_id = "TVENCIMIENTOSFACTURASVENTAS30"
        numeric_index = "TVENCIMIENTOSFACTURASVENTAS36"
        invoice_id = "TVENCIMIENTOSFACTURASVENTAS39"
        effect_mark_revised = "TVENCIMIENTOSFACTURASVENTAS42"
        claimed_count = "TVENCIMIENTOSFACTURASVENTAS44"
        anticipated = "TVENCIMIENTOSFACTURASVENTAS45"

    class SeriesAlbaranes:
        _tbl = "TSERIESALBARANES"
        series_code = "TSERIESALBARANES1"
        auto_counter = "TSERIESALBARANES2"
        last_code_used = "TSERIESALBARANES3"
        is_budget_billable = "TSERIESALBARANES4"
        is_part_not_billable = "TSERIESALBARANES5"
        credited_on_prices = "TSERIESALBARANES6"
        sell_devolution = "TSERIESALBARANES7"
        is_warranty_work = "TSERIESALBARANES8"
        maintenance_with_contract = "TSERIESALBARANES9"
        is_repair_contract = "TSERIESALBARANES10"
        is_automatic = "TSERIESALBARANES11"
        is_special = "TSERIESALBARANES12"
        is_others = "TSERIESALBARANES13"
        is_delivery = "TSERIESALBARANES14"
        is_project_certification = "TSERIESALBARANES15"
        is_outgoing_of_deposit = "TSERIESALBARANES16"
        is_pendant_of_resolution = "TSERIESALBARANES17"
        is_invoicing_without_cost = "TSERIESALBARANES51"

    class SeriesFacturacionVentas:
        _tbl = "TSERIESFACTURACIONVENTAS"
        code = "TSERIESFACTURACIONVENTAS1"
        desc = "TSERIESFACTURACIONVENTAS2"
        rectification_by_sustitution = "TSERIESFACTURACIONVENTAS5"
        rectification_by_negativ = "TSERIESFACTURACIONVENTAS6"
        rectification_by_difference = "TSERIESFACTURACIONVENTAS14"

    class StockAlmacenesUbicaciones:
        _tbl = "TSTOCKALMACENESUBICACIONES"
        warehouse = "TSTOCKALMACENESUBICACIONES1"
        article_ref = "TSTOCKALMACENESUBICACIONES2"
        amount = "TSTOCKALMACENESUBICACIONES4"

    class StockOtrosControles:
        _tbl = "TSTOCKOTROSCONTROLES"
        lot = "TSTOCKOTROSCONTROLES1"
        serial_number = "TSTOCKOTROSCONTROLES2"
        article_ref = "TSTOCKOTROSCONTROLES6"
        units = "TSTOCKOTROSCONTROLES8"
        provider = "TSTOCKOTROSCONTROLES10"
        warehouse = "TSTOCKOTROSCONTROLES11"

    class TareasTrazabilidad:
        _tbl = "TTAREASTRAZABILIDAD"
        date = "TTAREASTRAZABILIDAD1"
        time = "TTAREASTRAZABILIDAD2"
        state = "TTAREASTRAZABILIDAD3"
        worker = "TTAREASTRAZABILIDAD4"
        comments = "TTAREASTRAZABILIDAD5"
        ot_code = "TTAREASTRAZABILIDAD6"
        line_number = "TTAREASTRAZABILIDAD8"

    class TrabajosAvisos:
        _tbl = "TRABAJOSAVISOS"
        date = "TRABAJOSAVISOS1"
        worker_code = "TRABAJOSAVISOS2"
        worker_cat = "TRABAJOSAVISOS3"
        task_code = "TRABAJOSAVISOS4"
        time_start = "TRABAJOSAVISOS5"
        time_end = "TRABAJOSAVISOS6"
        time_real = "TRABAJOSAVISOS7"
        time_billable = "TRABAJOSAVISOS8"
        hour_type = "TRABAJOSAVISOS9"
        pvp_accountant = "TRABAJOSAVISOS10"
        pvp = "TRABAJOSAVISOS11"
        discount = "TRABAJOSAVISOS12"
        cost_accountant = "TRABAJOSAVISOS13"
        cost = "TRABAJOSAVISOS14"
        part_code = "TRABAJOSAVISOS15"
        invoice_type = "TRABAJOSAVISOS17"
        warranty_type = "TRABAJOSAVISOS18"
        element_code = "TRABAJOSAVISOS19"
        task_desc = "TRABAJOSAVISOS20"
        position = "TRABAJOSAVISOS21"
        observations = "TRABAJOSAVISOS25"

    class TraspasosAlmacen:
        _tbl = "TTRASPASOSALMACEN"
        doc_nr = "TTRASPASOSALMACEN1"
        date = "TTRASPASOSALMACEN2"
        option_manual = "TTRASPASOSALMACEN3"
        option_automatic = "TTRASPASOSALMACEN4"
        currency = "TTRASPASOSALMACEN5"
        transfer_type = "TTRASPASOSALMACEN6"
        reduce_type = "TTRASPASOSALMACEN7"
        regulation_type = "TTRASPASOSALMACEN8"
        initial_existence_type = "TTRASPASOSALMACEN9"
        document_type = "TTRASPASOSALMACEN10"
        total_raw_materials_currency = "TTRASPASOSALMACEN11"
        total_raw_materials_internal = "TTRASPASOSALMACEN12"
        total_final_product_currency = "TTRASPASOSALMACEN13"
        total_final_product_internal = "TTRASPASOSALMACEN14"
        observations = "TTRASPASOSALMACEN15"
        order_number = "TTRASPASOSALMACEN16"
        location_origin = "TTRASPASOSALMACEN17"
        location_destiny = "TTRASPASOSALMACEN18"
        location_editions = "TTRASPASOSALMACEN19"
        production_series = "TTRASPASOSALMACEN20"
        production_number = "TTRASPASOSALMACEN21"
        material_exists_part_type = "TTRASPASOSALMACEN22"
        time = "TTRASPASOSALMACEN23"

    class ValoresCostesEspeciales:
        _tbl = "TVALORESCOSTESESPECIALES"
        worker_code = "TVALORESCOSTESESPECIALES1"
        hour_code = "TVALORESCOSTESESPECIALES2"
        pvp = "TVALORESCOSTESESPECIALES3"
        cost = "TVALORESCOSTESESPECIALES4"
        client_code = "TVALORESCOSTESESPECIALES5"
        project_code = "TVALORESCOSTESESPECIALES6"
        professional_category = "TVALORESCOSTESESPECIALES7"

    class ValoresPlanificacionAbastecimiento:
        _tbl = "TVALORESPLANIFICACIONABASTECIMIENTO"
        article_code = "TVALORESPLANIFICACIONABASTECIMIENTO1"
        unit = "TVALORESPLANIFICACIONABASTECIMIENTO2"
        quantity = "TVALORESPLANIFICACIONABASTECIMIENTO3"
        price = "TVALORESPLANIFICACIONABASTECIMIENTO4"
        price_internal = "TVALORESPLANIFICACIONABASTECIMIENTO5"
        discount = "TVALORESPLANIFICACIONABASTECIMIENTO6"
        net_price = "TVALORESPLANIFICACIONABASTECIMIENTO7"
        net_price_internal = "TVALORESPLANIFICACIONABASTECIMIENTO8"
        price_type = "TVALORESPLANIFICACIONABASTECIMIENTO9"
        provider_code = "TVALORESPLANIFICACIONABASTECIMIENTO10"
        amoount = "TVALORESPLANIFICACIONABASTECIMIENTO11"
        amount_internal = "TVALORESPLANIFICACIONABASTECIMIENTO12"
        offer = "TVALORESPLANIFICACIONABASTECIMIENTO13"
        offer_reference = "TVALORESPLANIFICACIONABASTECIMIENTO14"
        offer_observations = "TVALORESPLANIFICACIONABASTECIMIENTO15"
        tab_number = "TVALORESPLANIFICACIONABASTECIMIENTO16"
        tab_name = "TVALORESPLANIFICACIONABASTECIMIENTO17"
        line_type = "TVALORESPLANIFICACIONABASTECIMIENTO18"
        line_id = "TVALORESPLANIFICACIONABASTECIMIENTO19"
        soc = "TVALORESPLANIFICACIONABASTECIMIENTO20"
        line_document_number = "TVALORESPLANIFICACIONABASTECIMIENTO21"
        pieces = "TVALORESPLANIFICACIONABASTECIMIENTO22"
        cost_price = "TVALORESPLANIFICACIONABASTECIMIENTO23"
        cost_price_internal = "TVALORESPLANIFICACIONABASTECIMIENTO24"

    class ValoresPosiblesLocalizaciones:
        _tbl = "TVALORESPOSIBLESLOCALIZACIONESART"
        family_code = "TVALORESPOSIBLESLOCALIZACIONESART1"
        sub_family_code = "TVALORESPOSIBLESLOCALIZACIONESART2"
        group_code = "TVALORESPOSIBLESLOCALIZACIONESART3"
        article_code = "TVALORESPOSIBLESLOCALIZACIONESART4"
        warehouse_code = "TVALORESPOSIBLESLOCALIZACIONESART5"
        location = "TVALORESPOSIBLESLOCALIZACIONESART6"
 
    class ValoresPresupuestos:
        _tbl = "TVALORESPRESUPUESTOS"
        line_type = "TVALORESPRESUPUESTOS1"
        article_code = "TVALORESPRESUPUESTOS2"
        description_line = "TVALORESPRESUPUESTOS3"
        units = "TVALORESPRESUPUESTOS4"
        price = "TVALORESPRESUPUESTOS5"
        discount_line = "TVALORESPRESUPUESTOS12"
        amount = "TVALORESPRESUPUESTOS14"
        article_cost = "TVALORESPRESUPUESTOS17"
        buget_header = "TVALORESPRESUPUESTOS25"
        series = "TVALORESPRESUPUESTOS26"
        budget_code = "TVALORESPRESUPUESTOS27"
        units_x_units_uo = "TVALORESPRESUPUESTOS28"
        cost_uo = "TVALORESPRESUPUESTOS32"
        project = "TVALORESPRESUPUESTOS49"
        line = "TVALORESPRESUPUESTOS51"
        optional_line = "TVALORESPRESUPUESTOS53"

    class ValoresTraspasosAlmacen:
        _tbl = "TVALORESTRASPASOSALMACEN"
        document_number = "TVALORESTRASPASOSALMACEN1"
        article_ref = "TVALORESTRASPASOSALMACEN2"
        origin = "TVALORESTRASPASOSALMACEN3"
        destination = "TVALORESTRASPASOSALMACEN4"
        lot_number = "TVALORESTRASPASOSALMACEN5"
        serial_number = "TVALORESTRASPASOSALMACEN6"
        units = "TVALORESTRASPASOSALMACEN7"
        unit_price = "TVALORESTRASPASOSALMACEN8"
        unit_price_internal = "TVALORESTRASPASOSALMACEN9"
        transfer_type = "TVALORESTRASPASOSALMACEN10"
        amount = "TVALORESTRASPASOSALMACEN11"  # todo check if currency or internal
        amount_internal = "TVALORESTRASPASOSALMACEN12"
        units_regularized = "TVALORESTRASPASOSALMACEN13"
        expire_date = "TVALORESTRASPASOSALMACEN14"
        warranty_days = "TVALORESTRASPASOSALMACEN15"
        auto_numeric_line = "TVALORESTRASPASOSALMACEN16"
        classification_code = "TVALORESTRASPASOSALMACEN17"
        pieces = "TVALORESTRASPASOSALMACEN18"
        pieces_regularized = "TVALORESTRASPASOSALMACEN19"
        gmi = "TVALORESTRASPASOSALMACEN20"
        observations = "TVALORESTRASPASOSALMACEN21"
        localization_destiny = "TVALORESTRASPASOSALMACEN22"
        localization_origin = "TVALORESTRASPASOSALMACEN23"
        notification_warehouse = "TVALORESTRASPASOSALMACEN24"
        numeric_index = "TVALORESTRASPASOSALMACEN25"

    class ValoresVentas:
        _tbl = "TVALORESVENTAS"
        line_type = "TVALORESVENTAS1"
        code = "TVALORESVENTAS2"
        desc = "TVALORESVENTAS3"
        units = "TVALORESVENTAS4"
        pvp_internal = "TVALORESVENTAS5"  # todo check if currency or internal
        pvp = "TVALORESVENTAS6"
        time = "TVALORESVENTAS7"
        price_time_internal = "TVALORESVENTAS8"  # todo check if currency or internal
        price_time = "TVALORESVENTAS9"
        price_installed_internal = (
            "TVALORESVENTAS10"  # todo check if currency or internal
        )
        price_installed = "TVALORESVENTAS11"
        discount_percentage = "TVALORESVENTAS12"
        amount_accountant = "TVALORESVENTAS13"
        amount = "TVALORESVENTAS14"
        recalc_char = "TVALORESVENTAS15"
        article_cost_internal = (
            "TVALORESVENTAS16"  # TODO check if is currency Or internal
        )
        article_cost = "TVALORESVENTAS17"
        article_margin_percentage = "TVALORESVENTAS18"
        cost_time_internal = "TVALORESVENTAS19"  # TODO check if is currency Or internal
        cost_time = "TVALORESVENTAS20"
        margin_percentage = "TVALORESVENTAS21"
        tax_code = "TVALORESVENTAS22"
        recharge_equivalent_percentage = "TVALORESVENTAS23"
        tax_percentage = "TVALORESVENTAS24"
        budget_header_desc = "TVALORESVENTAS25"
        series_code = "TVALORESVENTAS26"
        delivery_note_code = "TVALORESVENTAS27"
        units_x_units_uo = "TVALORESVENTAS28"
        line_sell_document = "TVALORESVENTAS29"
        sheet = "TVALORESVENTAS30"
        pgc_account = "TVALORESVENTAS31"
        total_units_cost = "TVALORESVENTAS32"
        total_margin_percentage = "TVALORESVENTAS33"
        price_tax_included_intgernal = "TVALORESVENTAS34"
        price_tax_included = "TVALORESVENTAS35"
        description_1 = "TVALORESVENTAS36"
        description_2 = "TVALORESVENTAS37"
        description_3 = "TVALORESVENTAS38"
        pvp_internal = "TVALORESVENTAS39"
        image_access_dir = "TVALORESVENTAS40"
        consecutive_line_number = "TVALORESVENTAS41"
        price_per_unit = "TVALORESVENTAS42"
        devolution_reason_code = "TVALORESVENTAS43"
        measure_unit = "TVALORESVENTAS44"
        package_code = "TVALORESVENTAS45"
        package_units = "TVALORESVENTAS46"
        bruto = "TVALORESVENTAS47"
        tare = "TVALORESVENTAS48"
        package_tax_code = "TVALORESVENTAS49"
        input_control = "TVALORESVENTAS50"
        pieces = "TVALORESVENTAS51"
        pieces_x_units_UO = "TVALORESVENTAS52"
        client_code = "TVALORESVENTAS53"
        document_date = "TVALORESVENTAS54"
        currency = "TVALORESVENTAS55"
        project_code = "TVALORESVENTAS56"
        percentage_rapid_pay = "TVALORESVENTAS57"
        pending_for_delivery = "TVALORESVENTAS58"
        project_unit = "TVALORESVENTAS59"
        amount_sale = "TVALORESVENTAS60"
        line_printed = "TVALORESVENTAS61"
        budget_header_number = "TVALORESVENTAS62"
        pvp_original = "TVALORESVENTAS63"
        price_green_point_internal = "TVALORESVENTAS64"
        price_piece_green_point_internal = "TVALORESVENTAS65"
        height = "TVALORESVENTAS66"
        width = "TVALORESVENTAS67"
        thickness = "TVALORESVENTAS68"
        swinging = "TVALORESVENTAS69"  # TODO probable tenga otro concept ;)
        hand = "TVALORESVENTAS70"
        reserved_field_1 = "TVALORESVENTAS71"
        reserved_field_2 = "TVALORESVENTAS72"
        enroll_package_edi = "TVALORESVENTAS73"
        budget_reference = "TVALORESVENTAS74"
        task_code = "TVALORESVENTAS75"
        task_desc = "TVALORESVENTAS76"
        observations = "TVALORESVENTAS77"
        warehouse_notified = "TVALORESVENTAS78"
        auton_numeric_line = "TVALORESVENTAS79"
        amount_with_tax = "TVALORESVENTAS80"
        amount_with_tax_internal = "TVALORESVENTAS81"
        weight_for_taxing = "TVALORESVENTAS82"
        package_price_internal = "TVALORESVENTAS83"
        package_price = "TVALORESVENTAS84"

    class Ventas:
        _tbl = "TVENTAS"
        document_type = "TVENTAS1"
        document_series = "TVENTAS2"
        document_number = "TVENTAS3"
        invoice_series = "TVENTAS4"
        invoice_number = "TVENTAS5"
        invoice_date = "TVENTAS6"
        document_date = "TVENTAS7"
        your_order = "TVENTAS8"
        our_order = "TVENTAS9"
        project_code = "TVENTAS10"
        budget_code = "TVENTAS11"
        client_code = "TVENTAS12"
        billable = "TVENTAS13"
        update_stock = "TVENTAS14"
        route = "TVENTAS15"
        order_number = "TVENTAS16"
        payment_method_code = "TVENTAS17"
        comission_agent_code = "TVENTAS18"
        coeficient = "TVENTAS19"
        currency_code = "TVENTAS20"
        amount_discount_offers_internal = "TVENTAS21"
        amount_discount_offers = "TVENTAS22"
        prices_tax_included = "TVENTAS23"
        fact_mat_by_level = "TVENTAS24"
        time_level = "TVENTAS25"
        at_amount_hour_price_internal = "TVENTAS26"
        price_types = "TVENTAS28"
        gross_internal = "TVENTAS30"
        gross_currency = "TVENTAS31"
        margin_accountant = "TVENTAS36"
        margin_currency = "TVENTAS37"
        budget_series = "TVENTAS38"
        delivery_man = "TVENTAS39"
        base_internal_1 = "TVENTAS43"
        base_currency_1 = "TVENTAS44"
        tax_type_code_1 = "TVENTAS45"
        tax_amount_internal_1 = "TVENTAS46"
        tax_currency_1 = "TVENTAS47"
        tax_recharge_percentage_1 = "TVENTAS48"
        tax_recharge_value_1 = "TVENTAS49"
        tax_recharge_value_currency_1 = "TVENTAS50"
        base_internal_2 = "TVENTAS51"
        base_currency_2 = "TVENTAS52"
        tax_type_code_2 = "TVENTAS53"
        tax_amount_internal_2 = "TVENTAS54"
        tax_currency_2 = "TVENTAS55"
        tax_recharge_percentage_2 = "TVENTAS56"
        tax_recharge_value_2 = "TVENTAS57"
        tax_recharge_value_currency_2 = "TVENTAS58"
        base_internal_3 = "TVENTAS59"
        base_currency_3 = "TVENTAS60"
        tax_type_code_3 = "TVENTAS61"
        tax_amount_internal_3 = "TVENTAS62"
        tax_currency_3 = "TVENTAS63"
        tax_recharge_percentage_3 = "TVENTAS64"
        tax_recharge_value_3 = "TVENTAS65"
        tax_recharge_value_currency_3 = "TVENTAS66"
        base_internal_4 = "TVENTAS67"
        base_currency_4 = "TVENTAS68"
        tax_type_code_4 = "TVENTAS69"
        tax_amount_internal_4 = "TVENTAS70"
        tax_currency_4 = "TVENTAS71"
        tax_recharge_percentage_4 = "TVENTAS72"
        tax_recharge_value_4 = "TVENTAS73"
        tax_recharge_value_currency_4 = "TVENTAS74"
        total_internal = "TVENTAS75"
        total_currency = "TVENTAS76"
        language_code = "TVENTAS79"
        warehouse_exit_code = "TVENTAS81"
        cost_document_internal = "TVENTAS87"  # TODO check cambiado accountant por internal
        cost_document = "TVENTAS88"
        assign_time_for_the_whole_document = "TVENTAS90"
        show_all_tasks = "TVENTAS91"
        acumulate_by_task = "TVENTAS97"
        acumulate_by_hour_type = "TVENTAS98"
        tax_type_1 = "TVENTAS101"
        tax_type_2 = "TVENTAS102"
        tax_type_3 = "TVENTAS103"
        tax_type_4 = "TVENTAS104"
        authorization_id = "TVENTAS105"
        year = "TVENTAS106"
        transfer_costs_to_document = "TVENTAS112"
        direct_sell = "TVENTAS115"
        percentage_on_amounts ="TVENTAS122"
        certification_level = "TVENTAS125"
        worker_code = "TVENTAS128"
        vehicle_code = "TVENTAS133"
        tarif_name = "TVENTAS139"
        discount_rn_state_percentage_in_recalc = "TVENTAS144"
        preparer_code = "TVENTAS147"
        payment_method_desc = "TVENTAS152"
        tpv_code = "TVENTAS195"
        ticket_counter = "TVENTAS196"
        time = "TVENTAS217"
        turn_tpv = "TVENTAS240"
        observations = "TVENTAS283"

    class VentasOtrosControles:
        _tbl = "TVENTASOTROSCONTROLES"
        lot_number = "TVENTASOTROSCONTROLES1"
        serial_number = "TVENTASOTROSCONTROLES2"
        expire_date = "TVENTASOTROSCONTROLES3"
        days_warranty_buy = "TVENTASOTROSCONTROLES4"
        days_warranty_sell = "TVENTASOTROSCONTROLES5"
        article_ref = "TVENTASOTROSCONTROLES6"
        amount = "TVENTASOTROSCONTROLES7"
        details_installation_location = "TVENTASOTROSCONTROLES8"
        budget_series = "TVENTASOTROSCONTROLES9"
        budget_code = "TVENTASOTROSCONTROLES10"
        budget_line = "TVENTASOTROSCONTROLES11"
        include_in_description = "TVENTASOTROSCONTROLES12"
        units = "TVENTASOTROSCONTROLES13"
        units_per = "TVENTASOTROSCONTROLES14"
        document_date = "TVENTASOTROSCONTROLES15"
        client_code = "TVENTASOTROSCONTROLES16"
        warehouse_code = "TVENTASOTROSCONTROLES17"
        warranty_buy_end_date = "TVENTASOTROSCONTROLES18"
        auto_numeric_line = "TVENTASOTROSCONTROLES19"
        pieces = "TVENTASOTROSCONTROLES20"
        units_pieces = "TVENTASOTROSCONTROLES21"
        units_pieces_per = "TVENTASOTROSCONTROLES22"
        element_number = "TVENTASOTROSCONTROLES23"
        numeric_index = "TVENTASOTROSCONTROLES24"
        weights_1 = "TVENTASOTROSCONTROLES25"
        weights_2 = "TVENTASOTROSCONTROLES26"
        weights_3 = "TVENTASOTROSCONTROLES27"

    class CuentasTesoreria:
        _tbl = "CCUENTASTESORERIA"
        number = "CCUENTASTESORERIA1"
        name = "CCUENTASTESORERIA2"
        associated_account = "CCUENTASTESORERIA4"
        observations = "CCUENTASTESORERIA14"
        import_limit = "CCUENTASTESORERIA15"

    class RemesasClientes:
        _tbl = "TREMESASCLIENTES"
        bank_account_charge = "TREMESASCLIENTES1"
        date_deposit = "TREMESASCLIENTES2"
        date_start = "TREMESASCLIENTES3"
        date_end = "TREMESASCLIENTES4"
        number = "TREMESASCLIENTES5"
        only_remittable = "TREMESASCLIENTES6"
        andll = "TREMESASCLIENTES7"
        remitt_on_sight = "TREMESASCLIENTES8"
        dated = "TREMESASCLIENTES9"
        remitt_on_discount = "TREMESASCLIENTES10"
        selections_va_concepts = "TREMESASCLIENTES11"
        selection_of_clients = "TREMESASCLIENTES12"
        selection_of_bank_accounts = "TREMESASCLIENTES13"
        selection_of_invoices_series = "TREMESASCLIENTES14"
        selection_of_invoices = "TREMESASCLIENTES15"
        currency_selection = "TREMESASCLIENTES16"
        selection_of_all_pending_to_remit = "TREMESASCLIENTES17"
        amount_currency = "TREMESASCLIENTES18"
        amount_internal = "TREMESASCLIENTES19"
        limit_current_line = "TREMESASCLIENTES20"
        available = "TREMESASCLIENTES21"
        expenses_year = "TREMESASCLIENTES22"
        expenses_series = "TREMESASCLIENTES23"
        expenses_code = "TREMESASCLIENTES24"
        Currency = "TREMESASCLIENTES37"
        document_year = "TREMESASCLIENTES70"

    class TareasAvisos:
        _tbl = "TTAREASAVISOS"
        task_code = "TTAREASAVISOS1"
        task_desc = "TTAREASAVISOS2"
        task_observations = "TTAREASAVISOS3"
        ot_code = "TTAREASAVISOS4"
        auto_numeric_line = "TTAREASAVISOS5"
        theoretical_time = "TTAREASAVISOS6"
        line_index = "TTAREASAVISOS7"
        supervised = "TTAREASAVISOS8"

    class tObrasCalculos:
        _tbl = "TOBRASCALCULOS"
        project_code = "TOBRASCALCULOS1"
        project_group_code = "TOBRASCALCULOS8"
        calc_type = "TOBRASCALCULOS21"
        general_amount_budget = "TOBRASCALCULOS23"
        budget_material_units = "TOBRASCALCULOS25"
        budget_material_amount = "TOBRASCALCULOS26"
        budget_material_cost = "TOBRASCALCULOS27"
        budget_work_time_amount = "TOBRASCALCULOS29"
        budget_indirect_amount = "TOBRASCALCULOS32"
        budget_indirect_cost = "TOBRASCALCULOS33"
        general_amount_invoice = "TOBRASCALCULOS36"
        material_amount_invoice = "TOBRASCALCULOS40"
        material_cost_deliver = "TOBRASCALCULOS41"
        work_time_units_deliver = "TOBRASCALCULOS43"
        work_time_tax_invoice = "TOBRASCALCULOS44"
        work_time_cost_deliver = "TOBRASCALCULOS45"
        indirect_amount_invoice = "TOBRASCALCULOS48"
        indirect_cost_deliver = "TOBRASCALCULOS49"

    class Inmovilizados:
        _tbl = "TINMOVILIZADOS"
        code_pgc = "TINMOVILIZADOS1"
        currency = "TINMOVILIZADOS2"
        desc = "TINMOVILIZADOS3"
        variable_1 = "TINMOVILIZADOS4"
        variable_2 = "TINMOVILIZADOS5"
        variable_3 = "TINMOVILIZADOS6"
        variable_4 = "TINMOVILIZADOS7"
        inclusion_date = "TINMOVILIZADOS8"
        amount_currency = "TINMOVILIZADOS9"
        amount_internal = "TINMOVILIZADOS10"
        date_start = "TINMOVILIZADOS11"
        amortized_value = "TINMOVILIZADOS12"
        amortized_value_internal = "TINMOVILIZADOS13"
        residual_value = "TINMOVILIZADOS14"
        residual_value_internal = "TINMOVILIZADOS15"
        years = "TINMOVILIZADOS16"
        amortize_percentage = "TINMOVILIZADOS17"
        amortize_account_acum = "TINMOVILIZADOS18"
        amortize_expenses_account = "TINMOVILIZADOS19"
        annual = "TINMOVILIZADOS23"
        obsvervations = "TINMOVILIZADOS24"
        element = "TINMOVILIZADOS62"

    class CuotasAmortizacion:
        _tbl = "TCUOTASAMORTIZACION"
        date = "TCUOTASAMORTIZACION1"
        concept = "TCUOTASAMORTIZACION2"
        fee = "TCUOTASAMORTIZACION3"
        fee_internal = "TCUOTASAMORTIZACION4"
        accounted = "TCUOTASAMORTIZACION5"
        index_account_pgc = "TCUOTASAMORTIZACION6"
        index_line = "TCUOTASAMORTIZACION8"
        index_element_number = "TCUOTASAMORTIZACION9"

    class Seguimientos:
        _tbl = "TSEGUIMIENTOS"
        id = "TSEGUIMIENTOS1"
        date = "TSEGUIMIENTOS2"
        time = "TSEGUIMIENTOS3"
        person_code = "TSEGUIMIENTOS4"
        person_name = "TSEGUIMIENTOS5"
        worker_code = "TSEGUIMIENTOS6"
        worker_name = "TSEGUIMIENTOS7"
        contact_type = "TSEGUIMIENTOS8"
        contact_name = "TSEGUIMIENTOS9"
        article_code = "TSEGUIMIENTOS10"
        short_desc = "TSEGUIMIENTOS11"
        units = "TSEGUIMIENTOS12"
        project_code = "TSEGUIMIENTOS13"
        project_name = "TSEGUIMIENTOS14"
        desc = "TSEGUIMIENTOS15"
        manual_auto = "TSEGUIMIENTOS16"
        billable = "TSEGUIMIENTOS17"
        delivery_note_code = "TSEGUIMIENTOS18"
        attended = "TSEGUIMIENTOS19"
        # Descripción breve input
        internal_notes_short = "TSEGUIMIENTOS20"
        # Notas internas input
        internal_notes = "TSEGUIMIENTOS21"
        # Tiempo invertido en gestion
        time_invested = "TSEGUIMIENTOS22"
        # Gestiones por hora
        actions_per_hour = "TSEGUIMIENTOS23"
        # No considerar gestiones
        action_dont_treat_as = "TSEGUIMIENTOS24"
        # Confirmado SN
        confirmed_sn = "TSEGUIMIENTOS25"
        # Fecha atención
        attention_date = "TSEGUIMIENTOS26"
        time_attention_planned = "TSEGUIMIENTOS27"
        # Presupuesto
        budget_code = "TSEGUIMIENTOS29"
        # Características gestión
        managment_features = "TSEGUIMIENTOS30"
        # Avisar
        notify = "TSEGUIMIENTOS32"
        # Frecuencia del aviso
        notify_frequency = "TSEGUIMIENTOS33"
        # Aviso confirmado
        confirmed = "TSEGUIMIENTOS34"
        # Hora de aviso
        notify_time = "TSEGUIMIENTOS35"
        # Código Cliente
        client_code = "TSEGUIMIENTOS36"
        # Seguimiento del proveedor
        provider_tracing = "TSEGUIMIENTOS37"
        # Segumiento del empleado
        employee_tracing = "TSEGUIMIENTOS38"
        # Código Vehiculo
        vehicle_code = "TSEGUIMIENTOS39"
        # Fecha creación registro
        date_register_created = "TSEGUIMIENTOS40"
        # Usuario que cierra
        closing_user = "TSEGUIMIENTOS41"
        # Fecha de cierre
        closing_tme = "TSEGUIMIENTOS42"
        # Hora de cierre
        ClosingTime = "TSEGUIMIENTOS43"
        # Fecha de Creacioni nuevo
        creation_date = "TSEGUIMIENTOS44"
        # Fecha Notificacion
        notify_date = "TSEGUIMIENTOS45"

    class FechasPartidas:
        _tbl = "TFECHASPARTIDAS"
        name = "TFECHASPARTIDAS2"
        date_start = "TFECHASPARTIDAS3"
        date_end = "TFECHASPARTIDAS4"
        series = "TFECHASPARTIDAS5"
        budget_code = "TFECHASPARTIDAS6"

    class UnidadesDeObras:
        _tbl = "TUNIDADESOBRA"
        code = "TUNIDADESOBRA1"
        unit = "TUNIDADESOBRA2"
        currency = "TUNIDADESOBRA3"
        description = "TUNIDADESOBRA4"
        cost_time = "TUNIDADESOBRA11"
        bruto_currency_1 = "TUNIDADESOBRA13"
        cost_currency_1 = "TUNIDADESOBRA19"
        bruto_currency = "TUNIDADESOBRA28"
        bruto_currency_accounting = "TUNIDADESOBRA29"
        cost_currency = "TUNIDADESOBRA30"
        cost_currency_accounting = "TUNIDADESOBRA31"

    class ValoresUnidadesObra:
        _tbl = "TVALORESUNIDADESOBRA"
        article_code = "TVALORESUNIDADESOBRA1"
        description = "TVALORESUNIDADESOBRA2"
        count = "TVALORESUNIDADESOBRA3"
        pvp = "TVALORESUNIDADESOBRA4"
        cost = "TVALORESUNIDADESOBRA9"
        package_code = "TVALORESUNIDADESOBRA18"

    class ValoresGestionesObras:
        _tbl = "TVALORESGESTIONESOBRAS"
        project_code = "TVALORESUNIDADESOBRA1"
        management_code = "TVALORESUNIDADESOBRA2"
        date = "TVALORESUNIDADESOBRA3"
        comments = "TVALORESUNIDADESOBRA6"

    class Rutas:
        _tbl = "TRUTAS"
        code = "TRUTAS1"
        name = "TRUTAS2"
        default_agent = "TRUTAS3"
        last_delivery_man = "TRUTAS4"

    class ValoresRutas:
        _tbl = "TVALORESRUTAS"
        route_code = "TVALORESRUTAS1"
        order_code = "TVALORESRUTAS2"
        client_code = "TVALORESRUTAS3"

    class Cobros:
        _tbl = "tcobros"
        code = "tcobros1"
        type = "tcobros2"
        date_of_charge = "tcobros3"
        client_code = "tcobros4"
        # Número de efecto con que cobramos. (Nº Talon Nº Recibo  ...)
        effect_ref = "tcobros5"
        charge_mode_code = "tcobros6"
        date_expire = "tcobros7"
        expiration = "tcobros8"
        currency = "tcobros9"
        amount_currency = "tcobros10"
        amount_internal = "tcobros11"
        expenses_percent = "tcobros12"
        expenses_amount = "tcobros13"
        expenses_internal = "tcobros14"
        record_the_reception = "tcobros15"
        record_according_to = "tcobros16"
        dont_crate_seat = "tcobros17"
        pays_expenses_client = "tcobros18"
        pays_expenses_self = "tcobros19"
        diff_expenses_financial = "tcobros20"
        diff_expenses_change = "tcobros21"
        account_income_code = "tcobros22"
        account_change_diff_code = "tcobros23"
        account_financial_income_code = "tcobros24"
        account_expenses_code = "tcobros25"
        group_in_one = "tcobros26"
        simulate_charge = "tcobros27"
        # CostCenterCode ='tcobros28'
        client_payment_code = "tcobros29"
        includes_tax = "tcobros30"
        tax_invoice_expenses_1 = "tcobros31"
        tax_invoice_expenses_percentage_2 = "tcobros32"
        tax_invoice_expenes_amount_1 = "tcobros33"
        tax_invoice_expenes_amount_internal_1 = "tcobros34"
        invoice_expenses_code = "tcobros35"
        invoice_expenses_series = "tcobros36"
        count_expenses_invoice = "tcobros37"
        reserve_1 = "tcobros38"
        reserve_2 = "tcobros39"
        reserve_3 = "tcobros40"
        year = "tcobros41"
        invoice_code = "tcobros42"
        settle_and_leave_effect_in_situation = "tcobros43"
        # CCC = 'tcobros44'
        auto_close = "tcobros45"
        auto_close_key = "tcobros46"
        create_seat_on_compensation = "tcobros47"
        auto_generated = "tcobros48"
        liquidation_id = "tcobros49"
        liquidation_year = "tcobros50"
        tax_invoice_expenses_2 = "tcobros51"
        tax_invoice_expenses_percentage_2 = "tcobros52"
        tax_invoice_expenses_amount_2 = "tcobros53"
        tax_invoice_expenses_amount_internal_2 = "tcobros54"
        tax_invoice_expenses_3 = "tcobros55"
        tax_invoice_expenses_percentage_3 = "tcobros56"
        tax_invoice_expenses_amount_3 = "tcobros57"
        tax_invoice_expenses_amount_internal_3 = "tcobros58"
        account_exppenses_code_3 = "tcobros59"  # TODO check this order
        account_exppenses_code_2 = "tcobros60"
        account_exppenses_code_1 = "tcobros61"
        tax_base_expenses_1 = "tcobros62"
        tax_base_expenses_2 = "tcobros63"
        tax_base_expenses_3 = "tcobros64"
        tax_base_expenses_internal_1 = "tcobros65"
        tax_base_expenses_internal_2 = "tcobros66"
        tax_base_expenses_internal_3 = "tcobros67"

    class ValoresAlbaranesCompra:
        _tbl = "tValoresAlbaranesCompra"
        ref = "tValoresAlbaranesCompra1"
        desc = "tValoresAlbaranesCompra2"
        units = "tValoresAlbaranesCompra3"
        count = "tValoresAlbaranesCompra4"
        price = "tValoresAlbaranesCompra5"
        price_internal = "tValoresAlbaranesCompra6"
        discount_percentage = "tValoresAlbaranesCompra7"
        neto = "tValoresAlbaranesCompra8"
        neto_internal = "tValoresAlbaranesCompra9"
        price_type = "tValoresAlbaranesCompra10"
        price_total = "tValoresAlbaranesCompra11"
        price_total_internal = "tValoresAlbaranesCompra12"
        category = "tValoresAlbaranesCompra13"
        document_code = "tValoresAlbaranesCompra17"
        budget_sheet = "tValoresAlbaranesCompra18"
        document_date = "tValoresAlbaranesCompra19"
        provider_code = "tValoresAlbaranesCompra20"
        observations = "tValoresAlbaranesCompra23"
        line_type = "tValoresAlbaranesCompra24"
        document_line_id = "tValoresAlbaranesCompra25"
        account_pgc = "tValoresAlbaranesCompra26"
        tax_percentage = "tValoresAlbaranesCompra27"
        tax_ret_percentage = "tValoresAlbaranesCompra28"
        tax_type = "tValoresAlbaranesCompra29"
        project_code = "tValoresAlbaranesCompra30"
        units_total = "tValoresAlbaranesCompra31"
        numeric_index = "tValoresAlbaranesCompra32"
        desc_1 = "tValoresAlbaranesCompra33"
        desc_2 = "tValoresAlbaranesCompra34"
        desc_3 = "tValoresAlbaranesCompra35"
        desc_4 = "tValoresAlbaranesCompra36"
        tab_index = "tValoresAlbaranesCompra37"
        package = "tValoresAlbaranesCompra38"
        package_units = "tValoresAlbaranesCompra39"
        bruto = "tValoresAlbaranesCompra40"
        tar = "tValoresAlbaranesCompra41"
        cost = "tValoresAlbaranesCompra42"
        cost_internal = "tValoresAlbaranesCompra43"
        auto_numeric_line = "tValoresAlbaranesCompra44"
        pieces = "tValoresAlbaranesCompra45"
        pieces_total = "tValoresAlbaranesCompra46"
        price_base = "tValoresAlbaranesCompra50"
        price_base_internal = "tValoresAlbaranesCompra51"
        ccc = "tValoresAlbaranesCompra54"
        warehouse_in = "tValoresAlbaranesCompra55"
        budget_set = "tValoresAlbaranesCompra56"
        associated_order = "tValoresAlbaranesCompra57"

    class CostesIndirectos:
        _tbl = "tCostesIndirectos"
        date = "tCostesIndirectos1"
        currency = "tCostesIndirectos2"
        project_code = "tCostesIndirectos3"
        sheet = "tCostesIndirectos4"
        concept = "tCostesIndirectos5"
        accounting_amount = "tCostesIndirectos6"
        amount = "tCostesIndirectos7"
        year = "tCostesIndirectos8"
        series = "tCostesIndirectos9"
        purchase_doc = "tCostesIndirectos10"
        purchase_invoice = "tCostesIndirectos11"
        autonumbercab = "tCostesIndirectos12"
        classification = "tCostesIndirectos13"
        budget_series = "tCostesIndirectos14"
        budget_number = "tCostesIndirectos15"
        task_code = "tCostesIndirectos16"
        allocation_level_descriptor = "tCostesIndirectos15"

    class OtrosCostes:
        _tbl = "tRepartoInmovilizado"
        number = "tRepartoInmovilizado1"
        account_code = "tRepartoInmovilizado2"
        currency = "tRepartoInmovilizado3"
        amount = "tRepartoInmovilizado4"
        internal_value = "tRepartoInmovilizado5"
        date = "tRepartoInmovilizado6"
        document_number = "tRepartoInmovilizado7"
        concept = "tRepartoInmovilizado8"
        reparto_sheet = "tRepartoInmovilizado9"
        payment_type = "tRepartoInmovilizado10"
        internal_invoice_number = "tRepartoInmovilizado11"

    class ValoresOtroscostes:
        _tbl = "tValoresRepartoInmovilizado"
        asset_pgc_code = "tValoresRepartoInmovilizado1"
        element_number = "tValoresRepartoInmovilizado11"
        concept = "tValoresRepartoInmovilizado2"
        percentage = "tValoresRepartoInmovilizado3"
        amount = "tValoresRepartoInmovilizado4"
        internal_value = "tValoresRepartoInmovilizado5"
        type = "tValoresRepartoInmovilizado6"
        index_number = "tValoresRepartoInmovilizado7"
        route_code = "tValoresRepartoInmovilizado8"
        vendor_code = "tValoresRepartoInmovilizado9"
        autonumeric_line = "tValoresRepartoInmovilizado10"
        numeric_index = "tValoresRepartoInmovilizado12"

    class StockMinMaxAlmacen:
        _tbl = "almacenstockminimo"
        ref = "almacenstockminimo1"
        init_month = "almacenstockminimo2"
        end_month = "almacenstockminimo3"
        stock_min = "almacenstockminimo4"
        stock_max = "almacenstockminimo5"
        warehouse = "almacenstockminimo6"
        linautonumerico = "almacenstockminimo7"
        indexnumerico = "almacenstockminimo8"
